######################################################################
# Copyright (C) 2000 Carnegie Mellon University
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
#          Author: Todd Schrub <tls@cert.org>
#      Maintainer: Jed Pickel  <jed@pickel.net>, <jpickel@cert.org>
#
######################################################################
#
# This file generates three tables in any SQL92 compliant database
# that provide information useful when analyzing network data. These
# tables are intended to supplement the base tables required for 
# database support in snort in order to make data more human readable.
#
# Install:
#
# To install these tables, just run this file through a command line
# database client.
#
#    Mysql example: 
#    % zcat snortdb-extra.gz | mysql snort
#
#    Postgresql example:
#    % zcat snortdb-extra.gz | psql snort
#
#    unixODBC example:
#    % zcat snortdb-extra.gz | isql snort
# 
# Details:
#
# The three tables included are:
# 
#   protocols
#   ---------
#   This table provide an association between protocol number and name.
#   Data was collected from RFC1700.
#   +--------------------------+---------------------------------+
#   |  protocol    INT         | The protocol number             |
#   |  name        VARCHAR(50) | The protocol name               |
#   |  description VARCHAR(50) | Protocol description            |
#   +--------------------------+---------------------------------+
# 
#   services
#   ---------
#   Provide an association between port number, protocol, and service.
#   +--------------------------+---------------------------------+
#   | port         INT         | Decimal port number             |
#   | protocol     INT         | The protocol number             |
#   | name         VARCHAR(50) | The common service on that port |
#   | description  VARCHAR(255)| A description of the service    |
#   +--------------------------+---------------------------------+
# 
#   flags
#   ---------
#   Provides an association between the decimal representation of tcp
#   flags with sepcific flags.
# 
#   +---------------------------+-----------------------------------+
#   | number      INT           |  Decimal value of flags           |
#   | RES1        INT           |  1 if RES1 bit is active          |
#   | RES2        INT           |  1 if RES2 bit is active          |
#   | URG         INT           |       URG     |                   |
#   | ACK         INT           |       ACK     |                   |
#   | PSH         INT           |       PSH     |                   |
#   | RST         INT           |       RST     |                   |
#   | SYN         INT           |       SYN   \ | /                 |
#   | FIN         INT           |       FIN    \|/                  |
#   | valid       INT           |  1 if combination is valid        |
#   | description VARCHAR(255)  |  Common description if available  |
#   +---------------------------+-----------------------------------+

CREATE TABLE protocols(
       protocol    INT,    
       name        VARCHAR(50),    
       description VARCHAR(50)
);

CREATE TABLE services(
       port        INT,
       protocol    INT,
       name        VARCHAR(50),
       description VARCHAR(255)
);

CREATE TABLE flags(
       number      INT,
       RES1        INT,
       RES2        INT,
       URG         INT,
       ACK         INT,
       PSH         INT,
       RST         INT,
       SYN         INT,
       FIN         INT,
       valid       INT,
       description VARCHAR(255)
);

INSERT INTO protocols (protocol, name, description) VALUES(0, '-', 'Reserved');
INSERT INTO protocols (protocol, name, description) VALUES(1, 'ICMP', 'Internet');
INSERT INTO protocols (protocol, name, description) VALUES(2, 'IGMP', 'Internet');
INSERT INTO protocols (protocol, name, description) VALUES(3, 'GGP', 'Gateway-to-Gateway');
INSERT INTO protocols (protocol, name, description) VALUES(4, 'IP', 'IP');
INSERT INTO protocols (protocol, name, description) VALUES(5, 'ST', 'Stream');
INSERT INTO protocols (protocol, name, description) VALUES(6, 'TCP', 'Transmission');
INSERT INTO protocols (protocol, name, description) VALUES(7, 'UCL', 'UCL');
INSERT INTO protocols (protocol, name, description) VALUES(8, 'EGP', 'Exterior');
INSERT INTO protocols (protocol, name, description) VALUES(9, 'IGP', 'any');
INSERT INTO protocols (protocol, name, description) VALUES(10, 'BBN-RCC-MON', 'BBN');
INSERT INTO protocols (protocol, name, description) VALUES(11, 'NVP-II', 'Network');
INSERT INTO protocols (protocol, name, description) VALUES(12, 'PUP', 'PUP');
INSERT INTO protocols (protocol, name, description) VALUES(13, 'ARGUS', 'ARGUS');
INSERT INTO protocols (protocol, name, description) VALUES(14, 'EMCON', 'EMCON');
INSERT INTO protocols (protocol, name, description) VALUES(15, 'XNET', 'Cross');
INSERT INTO protocols (protocol, name, description) VALUES(16, 'CHAOS', 'Chaos');
INSERT INTO protocols (protocol, name, description) VALUES(17, 'UDP', 'User');
INSERT INTO protocols (protocol, name, description) VALUES(18, 'MUX', 'Multiplexing');
INSERT INTO protocols (protocol, name, description) VALUES(19, 'DCN-MEAS', 'DCN');
INSERT INTO protocols (protocol, name, description) VALUES(20, 'HMP', 'Host');
INSERT INTO protocols (protocol, name, description) VALUES(21, 'PRM', 'Packet');
INSERT INTO protocols (protocol, name, description) VALUES(22, 'XNS-IDP', 'XEROX');
INSERT INTO protocols (protocol, name, description) VALUES(23, 'TRUNK-1', 'Trunk-1');
INSERT INTO protocols (protocol, name, description) VALUES(24, 'TRUNK-2', 'Trunk-2');
INSERT INTO protocols (protocol, name, description) VALUES(25, 'LEAF-1', 'Leaf-1');
INSERT INTO protocols (protocol, name, description) VALUES(26, 'LEAF-2', 'Leaf-2');
INSERT INTO protocols (protocol, name, description) VALUES(27, 'RDP', 'Reliable');
INSERT INTO protocols (protocol, name, description) VALUES(28, 'IRTP', 'Internet');
INSERT INTO protocols (protocol, name, description) VALUES(29, 'ISO-TP4', 'ISO');
INSERT INTO protocols (protocol, name, description) VALUES(30, 'NETBLT', 'Bulk');
INSERT INTO protocols (protocol, name, description) VALUES(31, 'MFE-NSP', 'MFE');
INSERT INTO protocols (protocol, name, description) VALUES(32, 'MERIT-INP', 'MERIT');
INSERT INTO protocols (protocol, name, description) VALUES(33, 'SEP', 'Sequential');
INSERT INTO protocols (protocol, name, description) VALUES(34, '3PC', 'Third');
INSERT INTO protocols (protocol, name, description) VALUES(35, 'IDPR', 'Inter-Domain');
INSERT INTO protocols (protocol, name, description) VALUES(36, 'XTP', 'XTP');
INSERT INTO protocols (protocol, name, description) VALUES(37, 'DDP', 'Datagram');
INSERT INTO protocols (protocol, name, description) VALUES(38, 'IDPR-CMTP', 'IDPR');
INSERT INTO protocols (protocol, name, description) VALUES(39, 'TP++', 'TP++');
INSERT INTO protocols (protocol, name, description) VALUES(40, 'IL', 'IL');
INSERT INTO protocols (protocol, name, description) VALUES(41, 'SIP', 'Simple');
INSERT INTO protocols (protocol, name, description) VALUES(42, 'SDRP', 'Source');
INSERT INTO protocols (protocol, name, description) VALUES(43, 'SIP-SR', 'SIP');
INSERT INTO protocols (protocol, name, description) VALUES(44, 'SIP-FRAG', 'SIP');
INSERT INTO protocols (protocol, name, description) VALUES(45, 'IDRP', 'Inter-Domain');
INSERT INTO protocols (protocol, name, description) VALUES(46, 'RSVP', 'Reservation');
INSERT INTO protocols (protocol, name, description) VALUES(47, 'GRE', 'General');
INSERT INTO protocols (protocol, name, description) VALUES(48, 'MHRP', 'Mobile');
INSERT INTO protocols (protocol, name, description) VALUES(49, 'BNA', 'BNA');
INSERT INTO protocols (protocol, name, description) VALUES(50, 'SIPP-ESP', 'SIPP');
INSERT INTO protocols (protocol, name, description) VALUES(51, 'SIPP-AH', 'SIPP');
INSERT INTO protocols (protocol, name, description) VALUES(52, 'I-NLSP', 'Integrated');
INSERT INTO protocols (protocol, name, description) VALUES(53, 'SWIPE', 'IP');
INSERT INTO protocols (protocol, name, description) VALUES(54, 'NHRP', 'NBMA');
INSERT INTO protocols (protocol, name, description) VALUES(55, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(51, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(52, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(53, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(54, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(55, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(56, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(57, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(58, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(59, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(60, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(61, '-', 'any');
INSERT INTO protocols (protocol, name, description) VALUES(62, 'CFTP', 'CFTP');
INSERT INTO protocols (protocol, name, description) VALUES(63, '-', 'any');
INSERT INTO protocols (protocol, name, description) VALUES(64, 'SAT-EXPAK', 'SATNET');
INSERT INTO protocols (protocol, name, description) VALUES(65, 'KRYPTOLAN', 'Kryptolan');
INSERT INTO protocols (protocol, name, description) VALUES(66, 'RVD', 'MIT');
INSERT INTO protocols (protocol, name, description) VALUES(67, 'IPPC', 'Internet');
INSERT INTO protocols (protocol, name, description) VALUES(68, '-', 'any');
INSERT INTO protocols (protocol, name, description) VALUES(69, 'SAT-MON', 'SATNET');
INSERT INTO protocols (protocol, name, description) VALUES(70, 'VISA', 'VISA');
INSERT INTO protocols (protocol, name, description) VALUES(71, 'IPCV', 'Internet');
INSERT INTO protocols (protocol, name, description) VALUES(72, 'CPNX', 'Computer');
INSERT INTO protocols (protocol, name, description) VALUES(73, 'CPHB', 'Computer');
INSERT INTO protocols (protocol, name, description) VALUES(74, 'WSN', 'Wang');
INSERT INTO protocols (protocol, name, description) VALUES(75, 'PVP', 'Packet');
INSERT INTO protocols (protocol, name, description) VALUES(76, 'BR-SAT-MON', 'Backroom');
INSERT INTO protocols (protocol, name, description) VALUES(77, 'SUN-ND', 'SUN');
INSERT INTO protocols (protocol, name, description) VALUES(78, 'WB-MON', 'WIDEBAND');
INSERT INTO protocols (protocol, name, description) VALUES(79, 'WB-EXPAK', 'WIDEBAND');
INSERT INTO protocols (protocol, name, description) VALUES(80, 'ISO-IP', 'ISO');
INSERT INTO protocols (protocol, name, description) VALUES(81, 'VMTP', 'VMTP');
INSERT INTO protocols (protocol, name, description) VALUES(82, 'SECURE-VMTP', 'SECURE-VMTP');
INSERT INTO protocols (protocol, name, description) VALUES(83, 'VINES', 'VINES');
INSERT INTO protocols (protocol, name, description) VALUES(84, 'TTP', 'TTP');
INSERT INTO protocols (protocol, name, description) VALUES(85, 'NSFNET-IGP', 'NSFNET-IGP');
INSERT INTO protocols (protocol, name, description) VALUES(86, 'DGP', 'Dissimilar');
INSERT INTO protocols (protocol, name, description) VALUES(87, 'TCF', 'TCF');
INSERT INTO protocols (protocol, name, description) VALUES(88, 'IGRP', 'IGRP');
INSERT INTO protocols (protocol, name, description) VALUES(89, 'OSPFIGP', 'OSPFIGP');
INSERT INTO protocols (protocol, name, description) VALUES(90, 'Sprite-RPC', 'Sprite');
INSERT INTO protocols (protocol, name, description) VALUES(91, 'LARP', 'Locus');
INSERT INTO protocols (protocol, name, description) VALUES(92, 'MTP', 'Multicast');
INSERT INTO protocols (protocol, name, description) VALUES(93, 'AX.25', 'AX.25');
INSERT INTO protocols (protocol, name, description) VALUES(94, 'IPIP', 'IP-within-IP');
INSERT INTO protocols (protocol, name, description) VALUES(95, 'MICP', 'Mobile');
INSERT INTO protocols (protocol, name, description) VALUES(96, 'SCC-SP', 'Semaphore');
INSERT INTO protocols (protocol, name, description) VALUES(97, 'ETHERIP', 'Ethernet-within-IP');
INSERT INTO protocols (protocol, name, description) VALUES(98, 'ENCAP', 'Encapsulation');
INSERT INTO protocols (protocol, name, description) VALUES(99, '-', 'any');
INSERT INTO protocols (protocol, name, description) VALUES(100, 'GMTP', 'GMTP');
INSERT INTO protocols (protocol, name, description) VALUES(101, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(102, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(103, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(104, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(105, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(106, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(107, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(108, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(109, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(110, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(111, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(112, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(113, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(114, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(115, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(116, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(117, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(118, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(119, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(120, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(121, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(122, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(123, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(124, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(125, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(126, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(127, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(128, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(129, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(130, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(131, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(132, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(133, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(134, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(135, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(136, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(137, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(138, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(139, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(140, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(141, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(142, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(143, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(144, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(145, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(146, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(147, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(148, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(149, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(150, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(151, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(152, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(153, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(154, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(155, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(156, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(157, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(158, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(159, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(160, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(161, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(162, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(163, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(164, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(165, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(166, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(167, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(168, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(169, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(170, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(171, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(172, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(173, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(174, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(175, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(176, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(177, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(178, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(179, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(180, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(181, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(182, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(183, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(184, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(185, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(186, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(187, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(188, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(189, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(190, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(191, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(192, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(193, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(194, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(195, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(196, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(197, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(198, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(199, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(200, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(201, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(202, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(203, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(204, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(205, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(206, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(207, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(208, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(209, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(210, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(211, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(212, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(213, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(214, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(215, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(216, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(217, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(218, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(219, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(220, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(221, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(222, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(223, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(224, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(225, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(226, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(227, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(228, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(229, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(230, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(231, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(232, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(233, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(234, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(235, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(236, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(237, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(238, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(239, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(240, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(241, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(242, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(243, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(244, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(245, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(246, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(247, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(248, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(249, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(250, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(251, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(252, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(253, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(254, '-', 'Unassigned');
INSERT INTO protocols (protocol, name, description) VALUES(255, '-', 'Reserved');

INSERT INTO services(port, protocol, name, description) VALUES('0', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('0', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1', '6', 'tcpmux', 'TCP Port Service Multiplexer');
INSERT INTO services(port, protocol, name, description) VALUES('1', '17', 'tcpmux', 'TCP Port Service Multiplexer');
INSERT INTO services(port, protocol, name, description) VALUES('2', '6', 'compressnet', 'Management Utility');
INSERT INTO services(port, protocol, name, description) VALUES('2', '17', 'compressnet', 'Management Utility');
INSERT INTO services(port, protocol, name, description) VALUES('3', '6', 'compressnet', 'Compression Process');
INSERT INTO services(port, protocol, name, description) VALUES('3', '17', 'compressnet', 'Compression Process');
INSERT INTO services(port, protocol, name, description) VALUES('4', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5', '6', 'rje', 'Remote Job Entry');
INSERT INTO services(port, protocol, name, description) VALUES('5', '17', 'rje', 'Remote Job Entry');
INSERT INTO services(port, protocol, name, description) VALUES('6', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7', '6', 'echo', 'Echo');
INSERT INTO services(port, protocol, name, description) VALUES('7', '17', 'echo', 'Echo');
INSERT INTO services(port, protocol, name, description) VALUES('8', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9', '6', 'discard', 'Discard');
INSERT INTO services(port, protocol, name, description) VALUES('9', '17', 'discard', 'Discard');
INSERT INTO services(port, protocol, name, description) VALUES('10', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11', '6', 'systat', 'Active Users');
INSERT INTO services(port, protocol, name, description) VALUES('11', '17', 'systat', 'Active Users');
INSERT INTO services(port, protocol, name, description) VALUES('12', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13', '6', 'daytime', 'Daytime');
INSERT INTO services(port, protocol, name, description) VALUES('13', '17', 'daytime', 'Daytime');
INSERT INTO services(port, protocol, name, description) VALUES('14', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17', '6', 'qotd', 'Quote of the Day');
INSERT INTO services(port, protocol, name, description) VALUES('17', '17', 'qotd', 'Quote of the Day');
INSERT INTO services(port, protocol, name, description) VALUES('18', '6', 'msp', 'Message Send Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('18', '17', 'msp', 'Message Send Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('19', '6', 'chargen', 'Character Generator');
INSERT INTO services(port, protocol, name, description) VALUES('19', '17', 'chargen', 'Character Generator');
INSERT INTO services(port, protocol, name, description) VALUES('20', '6', 'ftp-data', 'File Transfer [Default Data]');
INSERT INTO services(port, protocol, name, description) VALUES('20', '17', 'ftp-data', 'File Transfer [Default Data]');
INSERT INTO services(port, protocol, name, description) VALUES('21', '6', 'ftp', 'File Transfer [Control]');
INSERT INTO services(port, protocol, name, description) VALUES('21', '17', 'ftp', 'File Transfer [Control]');
INSERT INTO services(port, protocol, name, description) VALUES('22', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23', '6', 'telnet', 'Telnet');
INSERT INTO services(port, protocol, name, description) VALUES('23', '17', 'telnet', 'Telnet');
INSERT INTO services(port, protocol, name, description) VALUES('24', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25', '6', 'smtp', 'Simple Mail Transfer');
INSERT INTO services(port, protocol, name, description) VALUES('25', '17', 'smtp', 'Simple Mail Transfer');
INSERT INTO services(port, protocol, name, description) VALUES('26', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27', '6', 'nsw-fe', 'NSW User System FE');
INSERT INTO services(port, protocol, name, description) VALUES('27', '17', 'nsw-fe', 'NSW User System FE');
INSERT INTO services(port, protocol, name, description) VALUES('28', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29', '6', 'msg-icp', 'MSG ICP');
INSERT INTO services(port, protocol, name, description) VALUES('29', '17', 'msg-icp', 'MSG ICP');
INSERT INTO services(port, protocol, name, description) VALUES('30', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31', '6', 'msg-auth', 'MSG Authentication');
INSERT INTO services(port, protocol, name, description) VALUES('31', '17', 'msg-auth', 'MSG Authentication');
INSERT INTO services(port, protocol, name, description) VALUES('32', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33', '6', 'dsp', 'Display Support Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('33', '17', 'dsp', 'Display Support Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('34', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37', '6', 'time', 'Time');
INSERT INTO services(port, protocol, name, description) VALUES('37', '17', 'time', 'Time');
INSERT INTO services(port, protocol, name, description) VALUES('38', '6', 'rap', 'Route Access Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('38', '17', 'rap', 'Route Access Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('39', '6', 'rlp', 'Resource Location Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('39', '17', 'rlp', 'Resource Location Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('40', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41', '6', 'graphics', 'Graphics');
INSERT INTO services(port, protocol, name, description) VALUES('41', '17', 'graphics', 'Graphics');
INSERT INTO services(port, protocol, name, description) VALUES('42', '6', 'nameserver', 'Host Name Server');
INSERT INTO services(port, protocol, name, description) VALUES('42', '17', 'nameserver', 'Host Name Server');
INSERT INTO services(port, protocol, name, description) VALUES('43', '6', 'nicname', 'Who Is');
INSERT INTO services(port, protocol, name, description) VALUES('43', '17', 'nicname', 'Who Is');
INSERT INTO services(port, protocol, name, description) VALUES('44', '6', 'mpm-flags', 'MPM FLAGS Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('44', '17', 'mpm-flags', 'MPM FLAGS Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('45', '6', 'mpm', 'Message Processing Module [recv]');
INSERT INTO services(port, protocol, name, description) VALUES('45', '17', 'mpm', 'Message Processing Module [recv]');
INSERT INTO services(port, protocol, name, description) VALUES('46', '6', 'mpm-snd', 'MPM [default send]');
INSERT INTO services(port, protocol, name, description) VALUES('46', '17', 'mpm-snd', 'MPM [default send]');
INSERT INTO services(port, protocol, name, description) VALUES('47', '6', 'ni-ftp', 'NI FTP');
INSERT INTO services(port, protocol, name, description) VALUES('47', '17', 'ni-ftp', 'NI FTP');
INSERT INTO services(port, protocol, name, description) VALUES('48', '6', 'auditd', 'Digital Audit Daemon');
INSERT INTO services(port, protocol, name, description) VALUES('48', '17', 'auditd', 'Digital Audit Daemon');
INSERT INTO services(port, protocol, name, description) VALUES('49', '6', 'login', 'Login Host Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('49', '17', 'login', 'Login Host Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('50', '6', 're-mail-ck', 'Remote Mail Checking Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('50', '17', 're-mail-ck', 'Remote Mail Checking Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('51', '6', 'la-maint', 'IMP Logical Address Maintenance');
INSERT INTO services(port, protocol, name, description) VALUES('51', '17', 'la-maint', 'IMP Logical Address Maintenance');
INSERT INTO services(port, protocol, name, description) VALUES('52', '6', 'xns-time', 'XNS Time Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('52', '17', 'xns-time', 'XNS Time Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('53', '6', 'domain', 'Domain Name Server');
INSERT INTO services(port, protocol, name, description) VALUES('53', '17', 'domain', 'Domain Name Server');
INSERT INTO services(port, protocol, name, description) VALUES('54', '6', 'xns-ch', 'XNS Clearinghouse');
INSERT INTO services(port, protocol, name, description) VALUES('54', '17', 'xns-ch', 'XNS Clearinghouse');
INSERT INTO services(port, protocol, name, description) VALUES('55', '6', 'isi-gl', 'ISI Graphics Language');
INSERT INTO services(port, protocol, name, description) VALUES('55', '17', 'isi-gl', 'ISI Graphics Language');
INSERT INTO services(port, protocol, name, description) VALUES('56', '6', 'xns-auth', 'XNS Authentication');
INSERT INTO services(port, protocol, name, description) VALUES('56', '17', 'xns-auth', 'XNS Authentication');
INSERT INTO services(port, protocol, name, description) VALUES('57', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58', '6', 'xns-mail', 'XNS Mail');
INSERT INTO services(port, protocol, name, description) VALUES('58', '17', 'xns-mail', 'XNS Mail');
INSERT INTO services(port, protocol, name, description) VALUES('59', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61', '6', 'ni-mail', 'NI MAIL');
INSERT INTO services(port, protocol, name, description) VALUES('61', '17', 'ni-mail', 'NI MAIL');
INSERT INTO services(port, protocol, name, description) VALUES('62', '6', 'acas', 'ACA Services');
INSERT INTO services(port, protocol, name, description) VALUES('62', '17', 'acas', 'ACA Services');
INSERT INTO services(port, protocol, name, description) VALUES('63', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64', '6', 'covia', 'Communications Integrator (CI)');
INSERT INTO services(port, protocol, name, description) VALUES('64', '17', 'covia', 'Communications Integrator (CI)');
INSERT INTO services(port, protocol, name, description) VALUES('65', '6', 'tacacs-ds', 'TACACS-Database Service');
INSERT INTO services(port, protocol, name, description) VALUES('65', '17', 'tacacs-ds', 'TACACS-Database Service');
INSERT INTO services(port, protocol, name, description) VALUES('66', '6', 'sql*net', 'Oracle SQL*NET');
INSERT INTO services(port, protocol, name, description) VALUES('66', '17', 'sql*net', 'Oracle SQL*NET');
INSERT INTO services(port, protocol, name, description) VALUES('67', '6', 'bootps', 'Bootstrap Protocol Server');
INSERT INTO services(port, protocol, name, description) VALUES('67', '17', 'bootps', 'Bootstrap Protocol Server');
INSERT INTO services(port, protocol, name, description) VALUES('68', '6', 'bootpc', 'Bootstrap Protocol Client');
INSERT INTO services(port, protocol, name, description) VALUES('68', '17', 'bootpc', 'Bootstrap Protocol Client');
INSERT INTO services(port, protocol, name, description) VALUES('69', '6', 'tftp', 'Trivial File Transfer');
INSERT INTO services(port, protocol, name, description) VALUES('69', '17', 'tftp', 'Trivial File Transfer');
INSERT INTO services(port, protocol, name, description) VALUES('70', '6', 'gopher', 'Gopher');
INSERT INTO services(port, protocol, name, description) VALUES('70', '17', 'gopher', 'Gopher');
INSERT INTO services(port, protocol, name, description) VALUES('71', '6', 'netrjs-1', 'Remote Job Service');
INSERT INTO services(port, protocol, name, description) VALUES('71', '17', 'netrjs-1', 'Remote Job Service');
INSERT INTO services(port, protocol, name, description) VALUES('72', '6', 'netrjs-2', 'Remote Job Service');
INSERT INTO services(port, protocol, name, description) VALUES('72', '17', 'netrjs-2', 'Remote Job Service');
INSERT INTO services(port, protocol, name, description) VALUES('73', '6', 'netrjs-3', 'Remote Job Service');
INSERT INTO services(port, protocol, name, description) VALUES('73', '17', 'netrjs-3', 'Remote Job Service');
INSERT INTO services(port, protocol, name, description) VALUES('74', '6', 'netrjs-4', 'Remote Job Service');
INSERT INTO services(port, protocol, name, description) VALUES('74', '17', 'netrjs-4', 'Remote Job Service');
INSERT INTO services(port, protocol, name, description) VALUES('75', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('75', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('76', '6', 'deos', 'Distributed External Object Store');
INSERT INTO services(port, protocol, name, description) VALUES('76', '17', 'deos', 'Distributed External Object Store');
INSERT INTO services(port, protocol, name, description) VALUES('77', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('77', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('78', '6', 'vettcp', 'vettcp');
INSERT INTO services(port, protocol, name, description) VALUES('78', '17', 'vettcp', 'vettcp');
INSERT INTO services(port, protocol, name, description) VALUES('79', '6', 'finger', 'Finger');
INSERT INTO services(port, protocol, name, description) VALUES('79', '17', 'finger', 'Finger');
INSERT INTO services(port, protocol, name, description) VALUES('80', '6', 'www-http', 'World Wide Web HTTP');
INSERT INTO services(port, protocol, name, description) VALUES('80', '17', 'www-http', 'World Wide Web HTTP');
INSERT INTO services(port, protocol, name, description) VALUES('81', '6', 'hosts2-ns', 'HOSTS2 Name Server');
INSERT INTO services(port, protocol, name, description) VALUES('81', '17', 'hosts2-ns', 'HOSTS2 Name Server');
INSERT INTO services(port, protocol, name, description) VALUES('82', '6', 'xfer', 'XFER Utility');
INSERT INTO services(port, protocol, name, description) VALUES('82', '17', 'xfer', 'XFER Utility');
INSERT INTO services(port, protocol, name, description) VALUES('83', '6', 'mit-ml-dev', 'MIT ML Device');
INSERT INTO services(port, protocol, name, description) VALUES('83', '17', 'mit-ml-dev', 'MIT ML Device');
INSERT INTO services(port, protocol, name, description) VALUES('84', '6', 'ctf', 'Common Trace Facility');
INSERT INTO services(port, protocol, name, description) VALUES('84', '17', 'ctf', 'Common Trace Facility');
INSERT INTO services(port, protocol, name, description) VALUES('85', '6', 'mit-ml-dev', 'MIT ML Device');
INSERT INTO services(port, protocol, name, description) VALUES('85', '17', 'mit-ml-dev', 'MIT ML Device');
INSERT INTO services(port, protocol, name, description) VALUES('86', '6', 'mfcobol', 'Micro Focus Cobol');
INSERT INTO services(port, protocol, name, description) VALUES('86', '17', 'mfcobol', 'Micro Focus Cobol');
INSERT INTO services(port, protocol, name, description) VALUES('87', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('87', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('88', '6', 'kerberos', 'Kerberos');
INSERT INTO services(port, protocol, name, description) VALUES('88', '17', 'kerberos', 'Kerberos');
INSERT INTO services(port, protocol, name, description) VALUES('89', '6', 'su-mit-tg', 'SU/MIT Telnet Gateway');
INSERT INTO services(port, protocol, name, description) VALUES('89', '17', 'su-mit-tg', 'SU/MIT Telnet Gateway');
INSERT INTO services(port, protocol, name, description) VALUES('90', '6', 'dnsix', 'DNSIX Securit Attribute Token Map');
INSERT INTO services(port, protocol, name, description) VALUES('90', '17', 'dnsix', 'DNSIX Securit Attribute Token Map');
INSERT INTO services(port, protocol, name, description) VALUES('91', '6', 'mit-dov', 'MIT Dover Spooler');
INSERT INTO services(port, protocol, name, description) VALUES('91', '17', 'mit-dov', 'MIT Dover Spooler');
INSERT INTO services(port, protocol, name, description) VALUES('92', '6', 'npp', 'Network Printing Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('92', '17', 'npp', 'Network Printing Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('93', '6', 'dcp', 'Device Control Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('93', '17', 'dcp', 'Device Control Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('94', '6', 'objcall', 'Tivoli Object Dispatcher');
INSERT INTO services(port, protocol, name, description) VALUES('94', '17', 'objcall', 'Tivoli Object Dispatcher');
INSERT INTO services(port, protocol, name, description) VALUES('95', '6', 'supdup', 'SUPDUP');
INSERT INTO services(port, protocol, name, description) VALUES('95', '17', 'supdup', 'SUPDUP');
INSERT INTO services(port, protocol, name, description) VALUES('96', '6', 'dixie', 'DIXIE Protocol Specification');
INSERT INTO services(port, protocol, name, description) VALUES('96', '17', 'dixie', 'DIXIE Protocol Specification');
INSERT INTO services(port, protocol, name, description) VALUES('97', '6', 'swift-rvf', 'Swift Remote Vitural File Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('97', '17', 'swift-rvf', 'Swift Remote Vitural File Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('98', '6', 'tacnews', 'TAC News');
INSERT INTO services(port, protocol, name, description) VALUES('98', '17', 'tacnews', 'TAC News');
INSERT INTO services(port, protocol, name, description) VALUES('99', '6', 'metagram', 'Metagram Relay');
INSERT INTO services(port, protocol, name, description) VALUES('99', '17', 'metagram', 'Metagram Relay');
INSERT INTO services(port, protocol, name, description) VALUES('100', '6', 'newacct', '[unauthorized use]');
INSERT INTO services(port, protocol, name, description) VALUES('100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('101', '6', 'hostname', 'NIC Host Name Server');
INSERT INTO services(port, protocol, name, description) VALUES('101', '17', 'hostname', 'NIC Host Name Server');
INSERT INTO services(port, protocol, name, description) VALUES('102', '6', 'iso-tsap', 'ISO-TSAP');
INSERT INTO services(port, protocol, name, description) VALUES('102', '17', 'iso-tsap', 'ISO-TSAP');
INSERT INTO services(port, protocol, name, description) VALUES('103', '6', 'gppitnp', 'Genesis Point-to-Point Trans Net');
INSERT INTO services(port, protocol, name, description) VALUES('103', '17', 'gppitnp', 'Genesis Point-to-Point Trans Net');
INSERT INTO services(port, protocol, name, description) VALUES('104', '6', 'acr-nema', 'ACR-NEMA Digital Imag. & Comm. 300');
INSERT INTO services(port, protocol, name, description) VALUES('104', '17', 'acr-nema', 'ACR-NEMA Digital Imag. & Comm. 300');
INSERT INTO services(port, protocol, name, description) VALUES('105', '6', 'csnet-ns', 'Mailbox Name Nameserver');
INSERT INTO services(port, protocol, name, description) VALUES('105', '17', 'csnet-ns', 'Mailbox Name Nameserver');
INSERT INTO services(port, protocol, name, description) VALUES('106', '6', '3com-tsmux', '3COM-TSMUX');
INSERT INTO services(port, protocol, name, description) VALUES('106', '17', '3com-tsmux', '3COM-TSMUX');
INSERT INTO services(port, protocol, name, description) VALUES('107', '6', 'rtelnet', 'Remote Telnet Service');
INSERT INTO services(port, protocol, name, description) VALUES('107', '17', 'rtelnet', 'Remote Telnet Service');
INSERT INTO services(port, protocol, name, description) VALUES('108', '6', 'snagas', 'SNA Gateway Access Server');
INSERT INTO services(port, protocol, name, description) VALUES('108', '17', 'snagas', 'SNA Gateway Access Server');
INSERT INTO services(port, protocol, name, description) VALUES('109', '6', 'pop2', 'Post Office Protocol - Version 2');
INSERT INTO services(port, protocol, name, description) VALUES('109', '17', 'pop2', 'Post Office Protocol - Version 2');
INSERT INTO services(port, protocol, name, description) VALUES('110', '6', 'pop3', 'Post Office Protocol - Version 3');
INSERT INTO services(port, protocol, name, description) VALUES('110', '17', 'pop3', 'Post Office Protocol - Version 3');
INSERT INTO services(port, protocol, name, description) VALUES('111', '6', 'sunrpc', 'SUN Remote Procedure Call');
INSERT INTO services(port, protocol, name, description) VALUES('111', '17', 'sunrpc', 'SUN Remote Procedure Call');
INSERT INTO services(port, protocol, name, description) VALUES('112', '6', 'mcidas', 'McIDAS Data Transmission Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('112', '17', 'mcidas', 'McIDAS Data Transmission Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('113', '6', 'auth', 'Authentication Service');
INSERT INTO services(port, protocol, name, description) VALUES('113', '17', 'auth', 'Authentication Service');
INSERT INTO services(port, protocol, name, description) VALUES('114', '6', 'audionews', 'Audio News Multicast');
INSERT INTO services(port, protocol, name, description) VALUES('114', '17', 'audionews', 'Audio News Multicast');
INSERT INTO services(port, protocol, name, description) VALUES('115', '6', 'sftp', 'Simple File Transfer Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('115', '17', 'sftp', 'Simple File Transfer Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('116', '6', 'ansanotify', 'ANSA REX Notify');
INSERT INTO services(port, protocol, name, description) VALUES('116', '17', 'ansanotify', 'ANSA REX Notify');
INSERT INTO services(port, protocol, name, description) VALUES('117', '6', 'uucp-path', 'UUCP Path Service');
INSERT INTO services(port, protocol, name, description) VALUES('117', '17', 'uucp-path', 'UUCP Path Service');
INSERT INTO services(port, protocol, name, description) VALUES('118', '6', 'sqlserv', 'SQL Services');
INSERT INTO services(port, protocol, name, description) VALUES('118', '17', 'sqlserv', 'SQL Services');
INSERT INTO services(port, protocol, name, description) VALUES('119', '6', 'nntp', 'Network News Transfer Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('119', '17', 'nntp', 'Network News Transfer Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('120', '6', 'cfdptkt', 'CFDPTKT');
INSERT INTO services(port, protocol, name, description) VALUES('120', '17', 'cfdptkt', 'CFDPTKT');
INSERT INTO services(port, protocol, name, description) VALUES('121', '6', 'erpc', 'Encore Expedited Remote Pro.Call');
INSERT INTO services(port, protocol, name, description) VALUES('121', '17', 'erpc', 'Encore Expedited Remote Pro.Call');
INSERT INTO services(port, protocol, name, description) VALUES('122', '6', 'smakynet', 'SMAKYNET');
INSERT INTO services(port, protocol, name, description) VALUES('122', '17', 'smakynet', 'SMAKYNET');
INSERT INTO services(port, protocol, name, description) VALUES('123', '6', 'ntp', 'Network Time Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('123', '17', 'ntp', 'Network Time Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('124', '6', 'ansatrader', 'ANSA REX Trader');
INSERT INTO services(port, protocol, name, description) VALUES('124', '17', 'ansatrader', 'ANSA REX Trader');
INSERT INTO services(port, protocol, name, description) VALUES('125', '6', 'locus-map', 'Locus PC-Interface Net Map Ser');
INSERT INTO services(port, protocol, name, description) VALUES('125', '17', 'locus-map', 'Locus PC-Interface Net Map Ser');
INSERT INTO services(port, protocol, name, description) VALUES('126', '6', 'unitary', 'Unisys Unitary Login');
INSERT INTO services(port, protocol, name, description) VALUES('126', '17', 'unitary', 'Unisys Unitary Login');
INSERT INTO services(port, protocol, name, description) VALUES('127', '6', 'locus-con', 'Locus PC-Interface Conn Server');
INSERT INTO services(port, protocol, name, description) VALUES('127', '17', 'locus-con', 'Locus PC-Interface Conn Server');
INSERT INTO services(port, protocol, name, description) VALUES('128', '6', 'gss-xlicen', 'GSS X License Verification');
INSERT INTO services(port, protocol, name, description) VALUES('128', '17', 'gss-xlicen', 'GSS X License Verification');
INSERT INTO services(port, protocol, name, description) VALUES('129', '6', 'pwdgen', 'Password Generator Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('129', '17', 'pwdgen', 'Password Generator Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('130', '6', 'cisco-fna', 'cisco FNATIVE');
INSERT INTO services(port, protocol, name, description) VALUES('130', '17', 'cisco-fna', 'cisco FNATIVE');
INSERT INTO services(port, protocol, name, description) VALUES('131', '6', 'cisco-tna', 'cisco TNATIVE');
INSERT INTO services(port, protocol, name, description) VALUES('131', '17', 'cisco-tna', 'cisco TNATIVE');
INSERT INTO services(port, protocol, name, description) VALUES('132', '6', 'cisco-sys', 'cisco SYSMAINT');
INSERT INTO services(port, protocol, name, description) VALUES('132', '17', 'cisco-sys', 'cisco SYSMAINT');
INSERT INTO services(port, protocol, name, description) VALUES('133', '6', 'statsrv', 'Statistics Service');
INSERT INTO services(port, protocol, name, description) VALUES('133', '17', 'statsrv', 'Statistics Service');
INSERT INTO services(port, protocol, name, description) VALUES('134', '6', 'ingres-net', 'INGRES-NET Service');
INSERT INTO services(port, protocol, name, description) VALUES('134', '17', 'ingres-net', 'INGRES-NET Service');
INSERT INTO services(port, protocol, name, description) VALUES('135', '6', 'loc-srv', 'Location Service');
INSERT INTO services(port, protocol, name, description) VALUES('135', '17', 'loc-srv', 'Location Service');
INSERT INTO services(port, protocol, name, description) VALUES('136', '6', 'profile', 'PROFILE Naming System');
INSERT INTO services(port, protocol, name, description) VALUES('136', '17', 'profile', 'PROFILE Naming System');
INSERT INTO services(port, protocol, name, description) VALUES('137', '6', 'netbios-ns', 'NETBIOS Name Service');
INSERT INTO services(port, protocol, name, description) VALUES('137', '17', 'netbios-ns', 'NETBIOS Name Service');
INSERT INTO services(port, protocol, name, description) VALUES('138', '6', 'netbios-dgm', 'NETBIOS Datagram Service');
INSERT INTO services(port, protocol, name, description) VALUES('138', '17', 'netbios-dgm', 'NETBIOS Datagram Service');
INSERT INTO services(port, protocol, name, description) VALUES('139', '6', 'netbios-ssn', 'NETBIOS Session Service');
INSERT INTO services(port, protocol, name, description) VALUES('139', '17', 'netbios-ssn', 'NETBIOS Session Service');
INSERT INTO services(port, protocol, name, description) VALUES('140', '6', 'emfis-data', 'EMFIS Data Service');
INSERT INTO services(port, protocol, name, description) VALUES('140', '17', 'emfis-data', 'EMFIS Data Service');
INSERT INTO services(port, protocol, name, description) VALUES('141', '6', 'emfis-cntl', 'EMFIS Control Service');
INSERT INTO services(port, protocol, name, description) VALUES('141', '17', 'emfis-cntl', 'EMFIS Control Service');
INSERT INTO services(port, protocol, name, description) VALUES('142', '6', 'bl-idm', 'Britton-Lee IDM');
INSERT INTO services(port, protocol, name, description) VALUES('142', '17', 'bl-idm', 'Britton-Lee IDM');
INSERT INTO services(port, protocol, name, description) VALUES('143', '6', 'imap2', 'Interim Mail Access Protocol v2');
INSERT INTO services(port, protocol, name, description) VALUES('143', '17', 'imap2', 'Interim Mail Access Protocol v2');
INSERT INTO services(port, protocol, name, description) VALUES('144', '6', 'news', 'NewS');
INSERT INTO services(port, protocol, name, description) VALUES('144', '17', 'news', 'NewS');
INSERT INTO services(port, protocol, name, description) VALUES('145', '6', 'uaac', 'UAAC Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('145', '17', 'uaac', 'UAAC Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('146', '6', 'iso-tp0', 'ISO-IP0');
INSERT INTO services(port, protocol, name, description) VALUES('146', '17', 'iso-tp0', 'ISO-IP0');
INSERT INTO services(port, protocol, name, description) VALUES('147', '6', 'iso-ip', 'ISO-IP');
INSERT INTO services(port, protocol, name, description) VALUES('147', '17', 'iso-ip', 'ISO-IP');
INSERT INTO services(port, protocol, name, description) VALUES('148', '6', 'cronus', 'CRONUS-SUPPORT');
INSERT INTO services(port, protocol, name, description) VALUES('148', '17', 'cronus', 'CRONUS-SUPPORT');
INSERT INTO services(port, protocol, name, description) VALUES('149', '6', 'aed-512', 'AED 512 Emulation Service');
INSERT INTO services(port, protocol, name, description) VALUES('149', '17', 'aed-512', 'AED 512 Emulation Service');
INSERT INTO services(port, protocol, name, description) VALUES('150', '6', 'sql-net', 'SQL-NET');
INSERT INTO services(port, protocol, name, description) VALUES('150', '17', 'sql-net', 'SQL-NET');
INSERT INTO services(port, protocol, name, description) VALUES('151', '6', 'hems', 'HEMS');
INSERT INTO services(port, protocol, name, description) VALUES('151', '17', 'hems', 'HEMS');
INSERT INTO services(port, protocol, name, description) VALUES('152', '6', 'bftp', 'Background File Transfer Program');
INSERT INTO services(port, protocol, name, description) VALUES('152', '17', 'bftp', 'Background File Transfer Program');
INSERT INTO services(port, protocol, name, description) VALUES('153', '6', 'sgmp', 'SGMP');
INSERT INTO services(port, protocol, name, description) VALUES('153', '17', 'sgmp', 'SGMP');
INSERT INTO services(port, protocol, name, description) VALUES('154', '6', 'netsc-prod', 'NETSC');
INSERT INTO services(port, protocol, name, description) VALUES('154', '17', 'netsc-prod', 'NETSC');
INSERT INTO services(port, protocol, name, description) VALUES('155', '6', 'netsc-dev', 'NETSC');
INSERT INTO services(port, protocol, name, description) VALUES('155', '17', 'netsc-dev', 'NETSC');
INSERT INTO services(port, protocol, name, description) VALUES('156', '6', 'sqlsrv', 'SQL Service');
INSERT INTO services(port, protocol, name, description) VALUES('156', '17', 'sqlsrv', 'SQL Service');
INSERT INTO services(port, protocol, name, description) VALUES('157', '6', 'knet-cmp', 'KNET/VM Command/Message Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('157', '17', 'knet-cmp', 'KNET/VM Command/Message Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('158', '6', 'pcmail-srv', 'PCMail Server');
INSERT INTO services(port, protocol, name, description) VALUES('158', '17', 'pcmail-srv', 'PCMail Server');
INSERT INTO services(port, protocol, name, description) VALUES('159', '6', 'nss-routing', 'NSS-Routing');
INSERT INTO services(port, protocol, name, description) VALUES('159', '17', 'nss-routing', 'NSS-Routing');
INSERT INTO services(port, protocol, name, description) VALUES('160', '6', 'sgmp-traps', 'SGMP-TRAPS');
INSERT INTO services(port, protocol, name, description) VALUES('160', '17', 'sgmp-traps', 'SGMP-TRAPS');
INSERT INTO services(port, protocol, name, description) VALUES('161', '6', 'snmp', 'SNMP');
INSERT INTO services(port, protocol, name, description) VALUES('161', '17', 'snmp', 'SNMP');
INSERT INTO services(port, protocol, name, description) VALUES('162', '6', 'snmptrap', 'SNMPTRAP');
INSERT INTO services(port, protocol, name, description) VALUES('162', '17', 'snmptrap', 'SNMPTRAP');
INSERT INTO services(port, protocol, name, description) VALUES('163', '6', 'cmip-man', 'CMIP/TCP Manager');
INSERT INTO services(port, protocol, name, description) VALUES('163', '17', 'cmip-man', 'CMIP/TCP Manager');
INSERT INTO services(port, protocol, name, description) VALUES('164', '6', 'cmip-agent', 'CMIP/TCP Agent');
INSERT INTO services(port, protocol, name, description) VALUES('164', '17', 'smip-agent', 'CMIP/TCP Agent');
INSERT INTO services(port, protocol, name, description) VALUES('165', '6', 'xns-courier', 'Xerox');
INSERT INTO services(port, protocol, name, description) VALUES('165', '17', 'xns-courier', 'Xerox');
INSERT INTO services(port, protocol, name, description) VALUES('166', '6', 's-net', 'Sirius Systems');
INSERT INTO services(port, protocol, name, description) VALUES('166', '17', 's-net', 'Sirius Systems');
INSERT INTO services(port, protocol, name, description) VALUES('167', '6', 'namp', 'NAMP');
INSERT INTO services(port, protocol, name, description) VALUES('167', '17', 'namp', 'NAMP');
INSERT INTO services(port, protocol, name, description) VALUES('168', '6', 'rsvd', 'RSVD');
INSERT INTO services(port, protocol, name, description) VALUES('168', '17', 'rsvd', 'RSVD');
INSERT INTO services(port, protocol, name, description) VALUES('169', '6', 'send', 'SEND');
INSERT INTO services(port, protocol, name, description) VALUES('169', '17', 'send', 'SEND');
INSERT INTO services(port, protocol, name, description) VALUES('170', '6', 'print-srv', 'Network PostScript');
INSERT INTO services(port, protocol, name, description) VALUES('170', '17', 'print-srv', 'Network PostScript');
INSERT INTO services(port, protocol, name, description) VALUES('171', '6', 'multiplex', 'Network Innovations Multiplex');
INSERT INTO services(port, protocol, name, description) VALUES('171', '17', 'multiplex', 'Network Innovations Multiplex');
INSERT INTO services(port, protocol, name, description) VALUES('172', '6', 'cl/1', 'Network Innovations CL/1');
INSERT INTO services(port, protocol, name, description) VALUES('172', '17', 'cl/1', 'Network Innovations CL/1');
INSERT INTO services(port, protocol, name, description) VALUES('173', '6', 'xyplex-mux', 'Xyplex');
INSERT INTO services(port, protocol, name, description) VALUES('173', '17', 'xyplex-mux', 'Xyplex');
INSERT INTO services(port, protocol, name, description) VALUES('174', '6', 'mailq', 'MAILQ');
INSERT INTO services(port, protocol, name, description) VALUES('174', '17', 'mailq', 'MAILQ');
INSERT INTO services(port, protocol, name, description) VALUES('175', '6', 'vmnet', 'VMNET');
INSERT INTO services(port, protocol, name, description) VALUES('175', '17', 'vmnet', 'VMNET');
INSERT INTO services(port, protocol, name, description) VALUES('176', '6', 'genrad-mux', 'GENRAD-MUX');
INSERT INTO services(port, protocol, name, description) VALUES('176', '17', 'genrad-mux', 'GENRAD-MUX');
INSERT INTO services(port, protocol, name, description) VALUES('177', '6', 'xdmcp', 'X Display Manager Control Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('177', '17', 'xdmcp', 'X Display Manager Control Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('178', '6', 'nextstep', 'NextStep Window Server');
INSERT INTO services(port, protocol, name, description) VALUES('178', '17', 'NextStep', 'NextStep Window Server');
INSERT INTO services(port, protocol, name, description) VALUES('179', '6', 'bgp', 'Border Gateway Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('179', '17', 'bgp', 'Border Gateway Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('180', '6', 'ris', 'Intergraph');
INSERT INTO services(port, protocol, name, description) VALUES('180', '17', 'ris', 'Intergraph');
INSERT INTO services(port, protocol, name, description) VALUES('181', '6', 'unify', 'Unify');
INSERT INTO services(port, protocol, name, description) VALUES('181', '17', 'unify', 'Unify');
INSERT INTO services(port, protocol, name, description) VALUES('182', '6', 'audit', 'Unisys Audit SITP');
INSERT INTO services(port, protocol, name, description) VALUES('182', '17', 'audit', 'Unisys Audit SITP');
INSERT INTO services(port, protocol, name, description) VALUES('183', '6', 'ocbinder', 'OCBinder');
INSERT INTO services(port, protocol, name, description) VALUES('183', '17', 'ocbinder', 'OCBinder');
INSERT INTO services(port, protocol, name, description) VALUES('184', '6', 'ocserver', 'OCServer');
INSERT INTO services(port, protocol, name, description) VALUES('184', '17', 'ocserver', 'OCServer');
INSERT INTO services(port, protocol, name, description) VALUES('185', '6', 'remote-kis', 'Remote-KIS');
INSERT INTO services(port, protocol, name, description) VALUES('185', '17', 'remote-kis', 'Remote-KIS');
INSERT INTO services(port, protocol, name, description) VALUES('186', '6', 'kis', 'KIS Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('186', '17', 'kis', 'KIS Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('187', '6', 'aci', 'Application Communication Interface');
INSERT INTO services(port, protocol, name, description) VALUES('187', '17', 'aci', 'Application Communication Interface');
INSERT INTO services(port, protocol, name, description) VALUES('188', '6', 'mumps', 'Plus Five\'s MUMPS');
INSERT INTO services(port, protocol, name, description) VALUES('188', '17', 'mumps', 'Plus Five\'s MUMPS');
INSERT INTO services(port, protocol, name, description) VALUES('189', '6', 'qft', 'Queued File Transport');
INSERT INTO services(port, protocol, name, description) VALUES('189', '17', 'qft', 'Queued File Transport');
INSERT INTO services(port, protocol, name, description) VALUES('190', '6', 'gacp', 'Gateway Access Control Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('190', '17', 'cacp', 'Gateway Access Control Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('191', '6', 'prospero', 'Prospero Directory Service');
INSERT INTO services(port, protocol, name, description) VALUES('191', '17', 'prospero', 'Prospero Directory Service');
INSERT INTO services(port, protocol, name, description) VALUES('192', '6', 'osu-nms', 'OSU Network Monitoring System');
INSERT INTO services(port, protocol, name, description) VALUES('192', '17', 'osu-nms', 'OSU Network Monitoring System');
INSERT INTO services(port, protocol, name, description) VALUES('193', '6', 'srmp', 'Spider Remote Monitoring Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('193', '17', 'srmp', 'Spider Remote Monitoring Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('194', '6', 'irc', 'Internet Relay Chat Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('194', '17', 'irc', 'Internet Relay Chat Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('195', '6', 'dn6-nlm-aud', 'DNSIX Network Level Module Audit');
INSERT INTO services(port, protocol, name, description) VALUES('195', '17', 'dn6-nlm-aud', 'DNSIX Network Level Module Audit');
INSERT INTO services(port, protocol, name, description) VALUES('196', '6', 'dn6-smm-red', 'DNSIX Session Mgt Module Audit Redir');
INSERT INTO services(port, protocol, name, description) VALUES('196', '17', 'dn6-smm-red', 'DNSIX Session Mgt Module Audit Redir');
INSERT INTO services(port, protocol, name, description) VALUES('197', '6', 'dls', 'Directory Location Service');
INSERT INTO services(port, protocol, name, description) VALUES('197', '17', 'dls', 'Directory Location Service');
INSERT INTO services(port, protocol, name, description) VALUES('198', '6', 'dls-mon', 'Directory Location Service Monitor');
INSERT INTO services(port, protocol, name, description) VALUES('198', '17', 'dls-mon', 'Directory Location Service Monitor');
INSERT INTO services(port, protocol, name, description) VALUES('199', '6', 'smux', 'SMUX');
INSERT INTO services(port, protocol, name, description) VALUES('199', '17', 'smux', 'SMUX');
INSERT INTO services(port, protocol, name, description) VALUES('200', '6', 'src', 'IBM System Resource Controller');
INSERT INTO services(port, protocol, name, description) VALUES('200', '17', 'src', 'IBM System Resource Controller');
INSERT INTO services(port, protocol, name, description) VALUES('201', '6', 'at-rtmp', 'AppleTalk Routing Maintenance');
INSERT INTO services(port, protocol, name, description) VALUES('201', '17', 'at-rtmp', 'AppleTalk Routing Maintenance');
INSERT INTO services(port, protocol, name, description) VALUES('202', '6', 'at-nbp', 'AppleTalk Name Binding');
INSERT INTO services(port, protocol, name, description) VALUES('202', '17', 'at-nbp', 'AppleTalk Name Binding');
INSERT INTO services(port, protocol, name, description) VALUES('203', '6', 'at-3', 'AppleTalk Unused');
INSERT INTO services(port, protocol, name, description) VALUES('203', '17', 'at-3', 'AppleTalk Unused');
INSERT INTO services(port, protocol, name, description) VALUES('204', '6', 'at-echo', 'AppleTalk Echo');
INSERT INTO services(port, protocol, name, description) VALUES('204', '17', 'at-echo', 'AppleTalk Echo');
INSERT INTO services(port, protocol, name, description) VALUES('205', '6', 'at-5', 'AppleTalk Unused');
INSERT INTO services(port, protocol, name, description) VALUES('205', '17', 'at-5', 'AppleTalk Unused');
INSERT INTO services(port, protocol, name, description) VALUES('206', '6', 'at-zis', 'AppleTalk Zone Information');
INSERT INTO services(port, protocol, name, description) VALUES('206', '17', 'at-zis', 'AppleTalk Zone Information');
INSERT INTO services(port, protocol, name, description) VALUES('207', '6', 'at-7', 'AppleTalk Unused');
INSERT INTO services(port, protocol, name, description) VALUES('207', '17', 'at-7', 'AppleTalk Unused');
INSERT INTO services(port, protocol, name, description) VALUES('208', '6', 'at-8', 'AppleTalk Unused');
INSERT INTO services(port, protocol, name, description) VALUES('208', '17', 'at-8', 'AppleTalk Unused');
INSERT INTO services(port, protocol, name, description) VALUES('209', '6', 'tam', 'Trivial Authenticated Mail Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('209', '17', 'tam', 'Trivial Authenticated Mail Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('210', '6', 'z39.50', 'ANSI Z39.50');
INSERT INTO services(port, protocol, name, description) VALUES('210', '17', 'z39.50', 'ANSI Z39.50');
INSERT INTO services(port, protocol, name, description) VALUES('211', '6', '914c/g', 'Texas Instruments 914C/G Terminal');
INSERT INTO services(port, protocol, name, description) VALUES('211', '17', '914c/g', 'Texas Instruments 914C/G Terminal');
INSERT INTO services(port, protocol, name, description) VALUES('212', '6', 'anet', 'ATEXSSTR');
INSERT INTO services(port, protocol, name, description) VALUES('212', '17', 'anet', 'ATEXSSTR');
INSERT INTO services(port, protocol, name, description) VALUES('213', '6', 'ipx', 'IPX');
INSERT INTO services(port, protocol, name, description) VALUES('213', '17', 'ipx', 'IPX');
INSERT INTO services(port, protocol, name, description) VALUES('214', '6', 'vmpwscs', 'VM PWSCS');
INSERT INTO services(port, protocol, name, description) VALUES('214', '17', 'vmpwscs', 'VM PWSCS');
INSERT INTO services(port, protocol, name, description) VALUES('215', '6', 'softpc', 'Insignia Solutions');
INSERT INTO services(port, protocol, name, description) VALUES('215', '17', 'softpc', 'Insignia Solutions');
INSERT INTO services(port, protocol, name, description) VALUES('216', '6', 'atls', 'Access Technology License Server');
INSERT INTO services(port, protocol, name, description) VALUES('216', '17', 'atls', 'Access Technology License Server');
INSERT INTO services(port, protocol, name, description) VALUES('217', '6', 'dbase', 'dBASE Unix');
INSERT INTO services(port, protocol, name, description) VALUES('217', '17', 'dbase', 'dBASE Unix');
INSERT INTO services(port, protocol, name, description) VALUES('218', '6', 'mpp', 'Netix Message Posting Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('218', '17', 'mpp', 'Netix Message Posting Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('219', '6', 'uarps', 'Unisys ARPs');
INSERT INTO services(port, protocol, name, description) VALUES('219', '17', 'uarps', 'Unisys ARPs');
INSERT INTO services(port, protocol, name, description) VALUES('220', '6', 'imap3', 'Interactive Mail Access Protocol v3');
INSERT INTO services(port, protocol, name, description) VALUES('220', '17', 'imap3', 'Interactive Mail Access Protocol v3');
INSERT INTO services(port, protocol, name, description) VALUES('221', '6', 'fln-spx', 'Berkeley rlogind with SPX auth');
INSERT INTO services(port, protocol, name, description) VALUES('221', '17', 'fln-spx', 'Berkeley rlogind with SPX auth');
INSERT INTO services(port, protocol, name, description) VALUES('222', '6', 'rsh-spx', 'Berkeley rshd with SPX auth');
INSERT INTO services(port, protocol, name, description) VALUES('222', '17', 'rsh-spx', 'Berkeley rshd with SPX auth');
INSERT INTO services(port, protocol, name, description) VALUES('223', '6', 'cdc', 'Certificate Distribution Center');
INSERT INTO services(port, protocol, name, description) VALUES('223', '17', 'cdc', 'Certificate Distribution Center');
INSERT INTO services(port, protocol, name, description) VALUES('224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('243', '6', 'sur-meas', 'Survey Measurement');
INSERT INTO services(port, protocol, name, description) VALUES('243', '17', 'sur-meas', 'Survey Measurement');
INSERT INTO services(port, protocol, name, description) VALUES('244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('245', '6', 'link', 'LINK');
INSERT INTO services(port, protocol, name, description) VALUES('245', '17', 'link', 'LINK');
INSERT INTO services(port, protocol, name, description) VALUES('246', '6', 'dsp3270', 'Display Systems Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('246', '17', 'dsp3270', 'Display Systems Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('344', '6', 'pdap', 'Prospero Data Access Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('344', '17', 'pdap', 'Prospero Data Access Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('345', '6', 'pawserv', 'Perf Analysis Workbench');
INSERT INTO services(port, protocol, name, description) VALUES('345', '17', 'pawserv', 'Perf Analysis Workbench');
INSERT INTO services(port, protocol, name, description) VALUES('346', '6', 'zserv', 'Zebra server');
INSERT INTO services(port, protocol, name, description) VALUES('346', '17', 'zserv', 'Zebra server');
INSERT INTO services(port, protocol, name, description) VALUES('347', '6', 'fatserv', 'Fatmen Server');
INSERT INTO services(port, protocol, name, description) VALUES('347', '17', 'fatserv', 'Fatmen Server');
INSERT INTO services(port, protocol, name, description) VALUES('348', '6', 'csi-sgwp', 'Cabletron Management Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('348', '17', 'csi-sgwp', 'Cabletron Management Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('371', '6', 'clearcase', 'Clearcase');
INSERT INTO services(port, protocol, name, description) VALUES('371', '17', 'clearcase', 'Clearcase');
INSERT INTO services(port, protocol, name, description) VALUES('372', '6', 'ulistserv', 'Unix Listserv');
INSERT INTO services(port, protocol, name, description) VALUES('372', '17', 'ulistserv', 'Unix Listserv');
INSERT INTO services(port, protocol, name, description) VALUES('373', '6', 'legent-1', 'Legent Corporation');
INSERT INTO services(port, protocol, name, description) VALUES('373', '17', 'legent-1', 'Legent Corporation');
INSERT INTO services(port, protocol, name, description) VALUES('374', '6', 'legent-2', 'Legent Corporation');
INSERT INTO services(port, protocol, name, description) VALUES('374', '17', 'legent-2', 'Legent Corporation');
INSERT INTO services(port, protocol, name, description) VALUES('375', '6', 'hassle', 'Hassle');
INSERT INTO services(port, protocol, name, description) VALUES('375', '17', 'hassle', 'Hassle');
INSERT INTO services(port, protocol, name, description) VALUES('376', '6', 'nip', 'Amiga Envoy Network Inquiry Proto');
INSERT INTO services(port, protocol, name, description) VALUES('376', '17', 'nip', 'Amiga Envoy Network Inquiry Proto');
INSERT INTO services(port, protocol, name, description) VALUES('377', '6', 'tnETOS', 'NEC Corporation');
INSERT INTO services(port, protocol, name, description) VALUES('377', '17', 'tnETOS', 'NEC Corporation');
INSERT INTO services(port, protocol, name, description) VALUES('378', '6', 'dsETOS', 'NEC Corporation');
INSERT INTO services(port, protocol, name, description) VALUES('378', '17', 'dsETOS', 'NEC Corporation');
INSERT INTO services(port, protocol, name, description) VALUES('379', '6', 'is99c', 'TIA/EIA/IS-99 modem client');
INSERT INTO services(port, protocol, name, description) VALUES('379', '17', 'is99c', 'TIA/EIA/IS-99 modem client');
INSERT INTO services(port, protocol, name, description) VALUES('380', '6', 'is99s', 'TIA/EIA/IS-99 modem server');
INSERT INTO services(port, protocol, name, description) VALUES('380', '17', 'is99s', 'TIA/EIA/IS-99 modem server');
INSERT INTO services(port, protocol, name, description) VALUES('381', '6', 'hp-collector', 'hp performance data collector');
INSERT INTO services(port, protocol, name, description) VALUES('381', '17', 'hp-collector', 'hp performance data collector');
INSERT INTO services(port, protocol, name, description) VALUES('382', '6', 'hp-managed-node', 'hp performance data managed node');
INSERT INTO services(port, protocol, name, description) VALUES('382', '17', 'hp-managed-node', 'hp performance data managed node');
INSERT INTO services(port, protocol, name, description) VALUES('383', '6', 'hp-alarm-mgr', 'hp performance data alarm manager');
INSERT INTO services(port, protocol, name, description) VALUES('383', '17', 'hp-alarm-mgr', 'hp performance data alarm manager');
INSERT INTO services(port, protocol, name, description) VALUES('384', '6', 'arns', 'A Remote Network Server System');
INSERT INTO services(port, protocol, name, description) VALUES('384', '17', 'arns', 'A Remote Network Server System');
INSERT INTO services(port, protocol, name, description) VALUES('385', '6', 'ibm-app', 'IBM Application');
INSERT INTO services(port, protocol, name, description) VALUES('385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('386', '6', 'asa', 'ASA Message Router Object Def.');
INSERT INTO services(port, protocol, name, description) VALUES('386', '17', 'asa', 'ASA Message Router Object Def.');
INSERT INTO services(port, protocol, name, description) VALUES('387', '6', 'aurp', 'Appletalk Update-Based Routing Pro.');
INSERT INTO services(port, protocol, name, description) VALUES('387', '17', 'aurp', 'Appletalk Update-Based Routing Pro.');
INSERT INTO services(port, protocol, name, description) VALUES('388', '6', 'unidata-ldm', 'Unidata LDM Version 4');
INSERT INTO services(port, protocol, name, description) VALUES('388', '17', 'unidata-ldm', 'Unidata LDM Version 4');
INSERT INTO services(port, protocol, name, description) VALUES('389', '6', 'ldap', 'Lightweight Directory Access Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('389', '17', 'ldap', 'Lightweight Directory Access Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('390', '6', 'uis', 'UIS');
INSERT INTO services(port, protocol, name, description) VALUES('390', '17', 'uis', 'UIS');
INSERT INTO services(port, protocol, name, description) VALUES('391', '6', 'synotics-relay', 'SynOptics SNMP Relay Port');
INSERT INTO services(port, protocol, name, description) VALUES('391', '17', 'synotics-relay', 'SynOptics SNMP Relay Port');
INSERT INTO services(port, protocol, name, description) VALUES('392', '6', 'synotics-broker', 'SynOptics Port Broker Port');
INSERT INTO services(port, protocol, name, description) VALUES('392', '17', 'synotics-broker', 'SynOptics Port Broker Port');
INSERT INTO services(port, protocol, name, description) VALUES('393', '6', 'dis', 'Data Interpretation System');
INSERT INTO services(port, protocol, name, description) VALUES('393', '17', 'dis', 'Data Interpretation System');
INSERT INTO services(port, protocol, name, description) VALUES('394', '6', 'embl-ndt', 'EMBL Nucleic Data Transfer');
INSERT INTO services(port, protocol, name, description) VALUES('394', '17', 'embl-ndt', 'EMBL Nucleic Data Transfer');
INSERT INTO services(port, protocol, name, description) VALUES('395', '6', 'netcp', 'NETscout Control Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('395', '17', 'netcp', 'NETscout Control Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('396', '6', 'netware-ip', 'Novell Netware over IP');
INSERT INTO services(port, protocol, name, description) VALUES('396', '17', 'netware-ip', 'Novell Netware over IP');
INSERT INTO services(port, protocol, name, description) VALUES('397', '6', 'mptn', 'Multi Protocol Trans. Net.');
INSERT INTO services(port, protocol, name, description) VALUES('397', '17', 'mptn', 'Multi Protocol Trans. Net.');
INSERT INTO services(port, protocol, name, description) VALUES('398', '6', 'kryptolan', 'Kryptolan');
INSERT INTO services(port, protocol, name, description) VALUES('398', '17', 'kryptolan', 'Kryptolan');
INSERT INTO services(port, protocol, name, description) VALUES('399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('400', '6', 'work-sol', 'Workstation Solutions');
INSERT INTO services(port, protocol, name, description) VALUES('400', '17', 'work-sol', 'Workstation Solutions');
INSERT INTO services(port, protocol, name, description) VALUES('401', '6', 'ups', 'Uninterruptible Power Supply');
INSERT INTO services(port, protocol, name, description) VALUES('401', '17', 'ups', 'Uninterruptible Power Supply');
INSERT INTO services(port, protocol, name, description) VALUES('402', '6', 'genie', 'Genie Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('402', '17', 'genie', 'Genie Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('403', '6', 'decap', 'decap');
INSERT INTO services(port, protocol, name, description) VALUES('403', '17', 'decap', 'decap');
INSERT INTO services(port, protocol, name, description) VALUES('404', '6', 'nced', 'nced');
INSERT INTO services(port, protocol, name, description) VALUES('404', '17', 'nced', 'nced');
INSERT INTO services(port, protocol, name, description) VALUES('405', '6', 'ncld', 'ncld');
INSERT INTO services(port, protocol, name, description) VALUES('405', '17', 'ncld', 'ncld');
INSERT INTO services(port, protocol, name, description) VALUES('406', '6', 'imsp', 'Interactive Mail Support Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('406', '17', 'imsp', 'Interactive Mail Support Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('407', '6', 'timbuktu', 'Timbuktu');
INSERT INTO services(port, protocol, name, description) VALUES('407', '17', 'timbuktu', 'Timbuktu');
INSERT INTO services(port, protocol, name, description) VALUES('408', '6', 'prm-sm', 'Prospero Resource Manager Sys. Man.');
INSERT INTO services(port, protocol, name, description) VALUES('408', '17', 'prm-sm', 'Prospero Resource Manager Sys. Man.');
INSERT INTO services(port, protocol, name, description) VALUES('409', '6', 'prm-nm', 'Prospero Resource Manager Node Man.');
INSERT INTO services(port, protocol, name, description) VALUES('409', '17', 'prm-nm', 'Prospero Resource Manager Node Man.');
INSERT INTO services(port, protocol, name, description) VALUES('410', '6', 'decladebug', 'DECLadebug Remote Debug Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('410', '17', 'decladebug', 'DECLadebug Remote Debug Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('411', '6', 'rmt', 'Remote MT Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('411', '17', 'rmt', 'Remote MT Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('412', '6', 'synoptics-trap', 'Trap Convention Port');
INSERT INTO services(port, protocol, name, description) VALUES('412', '17', 'synoptics-trap', 'Trap Convention Port');
INSERT INTO services(port, protocol, name, description) VALUES('413', '6', 'smsp', 'SMSP');
INSERT INTO services(port, protocol, name, description) VALUES('413', '17', 'smsp', 'SMSP');
INSERT INTO services(port, protocol, name, description) VALUES('414', '6', 'infoseek', 'InfoSeek');
INSERT INTO services(port, protocol, name, description) VALUES('414', '17', 'infoseek', 'InfoSeek');
INSERT INTO services(port, protocol, name, description) VALUES('415', '6', 'bnet', 'BNet');
INSERT INTO services(port, protocol, name, description) VALUES('415', '17', 'bnet', 'BNet');
INSERT INTO services(port, protocol, name, description) VALUES('416', '6', 'silverplatter', 'Silverplatter');
INSERT INTO services(port, protocol, name, description) VALUES('416', '17', 'silverplatter', 'Silverplatter');
INSERT INTO services(port, protocol, name, description) VALUES('417', '6', 'onmux', 'Onmux');
INSERT INTO services(port, protocol, name, description) VALUES('417', '17', 'onmux', 'Onmux');
INSERT INTO services(port, protocol, name, description) VALUES('418', '6', 'hyper-g', 'Hyper-G');
INSERT INTO services(port, protocol, name, description) VALUES('418', '17', 'hyper-g', 'Hyper-G');
INSERT INTO services(port, protocol, name, description) VALUES('419', '6', 'ariel1', 'Ariel');
INSERT INTO services(port, protocol, name, description) VALUES('419', '17', 'ariel1', 'Ariel');
INSERT INTO services(port, protocol, name, description) VALUES('420', '6', 'smpte', 'SMPTE');
INSERT INTO services(port, protocol, name, description) VALUES('420', '17', 'smpte', 'SMPTE');
INSERT INTO services(port, protocol, name, description) VALUES('421', '6', 'ariel2', 'Ariel');
INSERT INTO services(port, protocol, name, description) VALUES('421', '17', 'ariel2', 'Ariel');
INSERT INTO services(port, protocol, name, description) VALUES('422', '6', 'ariel3', 'Ariel');
INSERT INTO services(port, protocol, name, description) VALUES('422', '17', 'ariel3', 'Ariel');
INSERT INTO services(port, protocol, name, description) VALUES('423', '6', 'opc-job-start', 'IBM Operations Planning and Control Start');
INSERT INTO services(port, protocol, name, description) VALUES('423', '17', 'opc-job-start', 'IBM Operations Planning and Control Start');
INSERT INTO services(port, protocol, name, description) VALUES('424', '6', 'opc-job-track', 'IBM Operations Planning and Control Track');
INSERT INTO services(port, protocol, name, description) VALUES('424', '17', 'opc-job-track', 'IBM Operations Planning and Control Track');
INSERT INTO services(port, protocol, name, description) VALUES('425', '6', 'icad-el', 'ICAD');
INSERT INTO services(port, protocol, name, description) VALUES('425', '17', 'icad-el', 'ICAD');
INSERT INTO services(port, protocol, name, description) VALUES('426', '6', 'smartsdp', 'smartsdp');
INSERT INTO services(port, protocol, name, description) VALUES('426', '17', 'smartsdp', 'smartsdp');
INSERT INTO services(port, protocol, name, description) VALUES('427', '6', 'svrloc', 'Server Location');
INSERT INTO services(port, protocol, name, description) VALUES('427', '17', 'svrloc', 'Server Location');
INSERT INTO services(port, protocol, name, description) VALUES('428', '6', 'ocs_cmu', 'OCS_CMU');
INSERT INTO services(port, protocol, name, description) VALUES('428', '17', 'ocs_cmu', 'OCS_CMU');
INSERT INTO services(port, protocol, name, description) VALUES('429', '6', 'ocs_amu', 'OCS_AMU');
INSERT INTO services(port, protocol, name, description) VALUES('429', '17', 'ocs_amu', 'OCS_AMU');
INSERT INTO services(port, protocol, name, description) VALUES('430', '6', 'utmpsd', 'UTMPSD');
INSERT INTO services(port, protocol, name, description) VALUES('430', '17', 'utmpsd', 'UTMPSD');
INSERT INTO services(port, protocol, name, description) VALUES('431', '6', 'utmpcd', 'UTMPCD');
INSERT INTO services(port, protocol, name, description) VALUES('431', '17', 'utmpcd', 'UTMPCD');
INSERT INTO services(port, protocol, name, description) VALUES('432', '6', 'iasd', 'IASD');
INSERT INTO services(port, protocol, name, description) VALUES('432', '17', 'iasd', 'IASD');
INSERT INTO services(port, protocol, name, description) VALUES('433', '6', 'nnsp', 'NNSP');
INSERT INTO services(port, protocol, name, description) VALUES('433', '17', 'nnsp', 'NNSP');
INSERT INTO services(port, protocol, name, description) VALUES('434', '6', 'mobileip-agent', 'MobileIP-Agent');
INSERT INTO services(port, protocol, name, description) VALUES('434', '17', 'mobileip-agent', 'MobileIP-Agent');
INSERT INTO services(port, protocol, name, description) VALUES('435', '6', 'mobilip-mn', 'MobilIP-MN');
INSERT INTO services(port, protocol, name, description) VALUES('435', '17', 'mobilip-mn', 'MobilIP-MN');
INSERT INTO services(port, protocol, name, description) VALUES('436', '6', 'dna-cml', 'DNA-CML');
INSERT INTO services(port, protocol, name, description) VALUES('436', '17', 'dna-cml', 'DNA-CML');
INSERT INTO services(port, protocol, name, description) VALUES('437', '6', 'comscm', 'comscm');
INSERT INTO services(port, protocol, name, description) VALUES('437', '17', 'comscm', 'comscm');
INSERT INTO services(port, protocol, name, description) VALUES('438', '6', 'dsfgw', 'dsfgw');
INSERT INTO services(port, protocol, name, description) VALUES('438', '17', 'dsfgw', 'dsfgw');
INSERT INTO services(port, protocol, name, description) VALUES('439', '6', 'dasp', 'dasp      Thomas Obermair');
INSERT INTO services(port, protocol, name, description) VALUES('439', '17', 'dasp', 'dasp      tommy@inlab.m.eunet.de');
INSERT INTO services(port, protocol, name, description) VALUES('440', '6', 'sgcp', 'sgcp');
INSERT INTO services(port, protocol, name, description) VALUES('440', '17', 'sgcp', 'sgcp');
INSERT INTO services(port, protocol, name, description) VALUES('441', '6', 'decvms-sysmgt', 'decvms-sysmgt');
INSERT INTO services(port, protocol, name, description) VALUES('441', '17', 'decvms-sysmgt', 'decvms-sysmgt');
INSERT INTO services(port, protocol, name, description) VALUES('442', '6', 'cvc_hostd', 'cvc_hostd');
INSERT INTO services(port, protocol, name, description) VALUES('442', '17', 'cvc_hostd', 'cvc_hostd');
INSERT INTO services(port, protocol, name, description) VALUES('443', '6', 'https', 'https  MCom');
INSERT INTO services(port, protocol, name, description) VALUES('443', '17', 'https', 'https  MCom');
INSERT INTO services(port, protocol, name, description) VALUES('444', '6', 'snpp', 'Simple Network Paging Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('444', '17', 'snpp', 'Simple Network Paging Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('445', '6', 'microsoft-ds', 'Microsoft-DS');
INSERT INTO services(port, protocol, name, description) VALUES('445', '17', 'microsoft-ds', 'Microsoft-DS');
INSERT INTO services(port, protocol, name, description) VALUES('446', '6', 'ddm-rdb', 'DDM-RDB');
INSERT INTO services(port, protocol, name, description) VALUES('446', '17', 'ddm-rdb', 'DDM-RDB');
INSERT INTO services(port, protocol, name, description) VALUES('447', '6', 'ddm-dfm', 'DDM-RFM');
INSERT INTO services(port, protocol, name, description) VALUES('447', '17', 'ddm-dfm', 'DDM-RFM');
INSERT INTO services(port, protocol, name, description) VALUES('448', '6', 'ddm-byte', 'DDM-BYTE');
INSERT INTO services(port, protocol, name, description) VALUES('448', '17', 'ddm-byte', 'DDM-BYTE');
INSERT INTO services(port, protocol, name, description) VALUES('449', '6', 'as-servermap', 'AS Server Mapper');
INSERT INTO services(port, protocol, name, description) VALUES('449', '17', 'as-servermap', 'AS Server Mapper');
INSERT INTO services(port, protocol, name, description) VALUES('450', '6', 'tserver', 'TServer');
INSERT INTO services(port, protocol, name, description) VALUES('450', '17', 'tserver', 'TServer');
INSERT INTO services(port, protocol, name, description) VALUES('451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('512', '6', 'exec', 'remote process execution;');
INSERT INTO services(port, protocol, name, description) VALUES('512', '17', 'biff', 'used by mail system to notify users');
INSERT INTO services(port, protocol, name, description) VALUES('513', '6', 'login', 'remote login a la telnet;');
INSERT INTO services(port, protocol, name, description) VALUES('513', '17', 'who', 'maintains data bases showing who\'s');
INSERT INTO services(port, protocol, name, description) VALUES('514', '6', 'cmd', 'like exec, but automatic');
INSERT INTO services(port, protocol, name, description) VALUES('514', '17', 'syslog', '');
INSERT INTO services(port, protocol, name, description) VALUES('515', '6', 'printer', 'spooler');
INSERT INTO services(port, protocol, name, description) VALUES('515', '17', 'printer', 'spooler');
INSERT INTO services(port, protocol, name, description) VALUES('516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('517', '6', 'talk', 'like tenex link, but across');
INSERT INTO services(port, protocol, name, description) VALUES('517', '17', 'talk', 'like tenex link, but across');
INSERT INTO services(port, protocol, name, description) VALUES('518', '6', 'ntalk', '');
INSERT INTO services(port, protocol, name, description) VALUES('518', '17', 'ntalk', '');
INSERT INTO services(port, protocol, name, description) VALUES('519', '6', 'utime', 'unixtime');
INSERT INTO services(port, protocol, name, description) VALUES('519', '17', 'utime', 'unixtime');
INSERT INTO services(port, protocol, name, description) VALUES('520', '6', 'efs', 'extended file name server');
INSERT INTO services(port, protocol, name, description) VALUES('520', '17', 'router', 'local routing process (on site);');
INSERT INTO services(port, protocol, name, description) VALUES('521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('525', '6', 'timed', 'timeserver');
INSERT INTO services(port, protocol, name, description) VALUES('525', '17', 'timed', 'timeserver');
INSERT INTO services(port, protocol, name, description) VALUES('526', '6', 'tempo', 'newdate');
INSERT INTO services(port, protocol, name, description) VALUES('526', '17', 'tempo', 'newdate');
INSERT INTO services(port, protocol, name, description) VALUES('527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('530', '6', 'courier', 'rpc');
INSERT INTO services(port, protocol, name, description) VALUES('530', '17', 'courier', 'rpc');
INSERT INTO services(port, protocol, name, description) VALUES('531', '6', 'conference', 'chat');
INSERT INTO services(port, protocol, name, description) VALUES('531', '17', 'conference', 'chat');
INSERT INTO services(port, protocol, name, description) VALUES('532', '6', 'netnews', 'readnews');
INSERT INTO services(port, protocol, name, description) VALUES('532', '17', 'netnews', 'readnews');
INSERT INTO services(port, protocol, name, description) VALUES('533', '6', 'netwall', 'for emergency broadcasts');
INSERT INTO services(port, protocol, name, description) VALUES('533', '17', 'netwall', 'for emergency broadcasts');
INSERT INTO services(port, protocol, name, description) VALUES('534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('539', '6', 'apertus-ldp', 'Apertus Technologies Load Determination');
INSERT INTO services(port, protocol, name, description) VALUES('539', '17', 'apertus-ldp', 'Apertus Technologies Load Determination');
INSERT INTO services(port, protocol, name, description) VALUES('540', '6', 'uucp', 'uucpd');
INSERT INTO services(port, protocol, name, description) VALUES('540', '17', 'uucp', 'uucpd');
INSERT INTO services(port, protocol, name, description) VALUES('541', '6', 'uucp-rlogin', 'uucp-rlogin  Stuart Lynne');
INSERT INTO services(port, protocol, name, description) VALUES('541', '17', 'uucp-rlogin', 'uucp-rlogin  sl@wimsey.com');
INSERT INTO services(port, protocol, name, description) VALUES('542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('543', '6', 'klogin', '');
INSERT INTO services(port, protocol, name, description) VALUES('543', '17', 'klogin', '');
INSERT INTO services(port, protocol, name, description) VALUES('544', '6', 'kshell', 'krcmd');
INSERT INTO services(port, protocol, name, description) VALUES('544', '17', 'kshell', 'krcmd');
INSERT INTO services(port, protocol, name, description) VALUES('545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('550', '6', 'new-rwho', 'new-who');
INSERT INTO services(port, protocol, name, description) VALUES('550', '17', 'new-rwho', 'new-who');
INSERT INTO services(port, protocol, name, description) VALUES('551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('555', '6', 'dsf', '');
INSERT INTO services(port, protocol, name, description) VALUES('555', '17', 'dsf', '');
INSERT INTO services(port, protocol, name, description) VALUES('556', '6', 'remotefs', 'rfs server');
INSERT INTO services(port, protocol, name, description) VALUES('556', '17', 'remotefs', 'rfs server');
INSERT INTO services(port, protocol, name, description) VALUES('557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('560', '6', 'rmonitor', 'rmonitord');
INSERT INTO services(port, protocol, name, description) VALUES('560', '17', 'rmonitor', 'rmonitord');
INSERT INTO services(port, protocol, name, description) VALUES('561', '6', 'monitor', '');
INSERT INTO services(port, protocol, name, description) VALUES('561', '17', 'monitor', '');
INSERT INTO services(port, protocol, name, description) VALUES('562', '6', 'chshell', 'chcmd');
INSERT INTO services(port, protocol, name, description) VALUES('562', '17', 'chshell', 'chcmd');
INSERT INTO services(port, protocol, name, description) VALUES('563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('564', '6', '9pfs', 'plan 9 file service');
INSERT INTO services(port, protocol, name, description) VALUES('564', '17', '9pfs', 'plan 9 file service');
INSERT INTO services(port, protocol, name, description) VALUES('565', '6', 'whoami', 'whoami');
INSERT INTO services(port, protocol, name, description) VALUES('565', '17', 'whoami', 'whoami');
INSERT INTO services(port, protocol, name, description) VALUES('566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('570', '6', 'meter', 'demon');
INSERT INTO services(port, protocol, name, description) VALUES('570', '17', 'meter', 'demon');
INSERT INTO services(port, protocol, name, description) VALUES('571', '6', 'meter', 'udemon');
INSERT INTO services(port, protocol, name, description) VALUES('571', '17', 'meter', 'udemon');
INSERT INTO services(port, protocol, name, description) VALUES('572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('600', '6', 'ipcserver', 'Sun IPC server');
INSERT INTO services(port, protocol, name, description) VALUES('600', '17', 'ipcserver', 'Sun IPC server');
INSERT INTO services(port, protocol, name, description) VALUES('601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('606', '6', 'urm', 'Cray Unified Resource Manager');
INSERT INTO services(port, protocol, name, description) VALUES('606', '17', 'urm', 'Cray Unified Resource Manager');
INSERT INTO services(port, protocol, name, description) VALUES('607', '6', 'nqs', 'nqs');
INSERT INTO services(port, protocol, name, description) VALUES('607', '17', 'nqs', 'nqs');
INSERT INTO services(port, protocol, name, description) VALUES('608', '6', 'sift-uft', 'Sender-Initiated/Unsolicited File Transfer');
INSERT INTO services(port, protocol, name, description) VALUES('608', '17', 'sift-uft', 'Sender-Initiated/Unsolicited File Transfer');
INSERT INTO services(port, protocol, name, description) VALUES('609', '6', 'npmp-trap', 'npmp-trap');
INSERT INTO services(port, protocol, name, description) VALUES('609', '17', 'npmp-trap', 'npmp-trap');
INSERT INTO services(port, protocol, name, description) VALUES('610', '6', 'npmp-local', 'npmp-local');
INSERT INTO services(port, protocol, name, description) VALUES('610', '17', 'npmp-local', 'npmp-local');
INSERT INTO services(port, protocol, name, description) VALUES('611', '6', 'npmp-gui', 'npmp-gui');
INSERT INTO services(port, protocol, name, description) VALUES('611', '17', 'npmp-gui', 'npmp-gui');
INSERT INTO services(port, protocol, name, description) VALUES('612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('634', '6', 'ginad', 'ginad');
INSERT INTO services(port, protocol, name, description) VALUES('634', '17', 'ginad', 'ginad');
INSERT INTO services(port, protocol, name, description) VALUES('635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('666', '6', 'doom', 'doom Id Software');
INSERT INTO services(port, protocol, name, description) VALUES('666', '17', 'mdqs', '');
INSERT INTO services(port, protocol, name, description) VALUES('667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('704', '6', 'elcsd', 'errlog copy/server daemon');
INSERT INTO services(port, protocol, name, description) VALUES('704', '17', 'elcsd', 'errlog copy/server daemon');
INSERT INTO services(port, protocol, name, description) VALUES('705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('709', '6', 'entrustmanager', 'EntrustManager');
INSERT INTO services(port, protocol, name, description) VALUES('709', '17', 'entrustmanager', 'EntrustManager');
INSERT INTO services(port, protocol, name, description) VALUES('710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('729', '6', 'netviewdm1', 'IBM NetView DM/6000 Server/Client');
INSERT INTO services(port, protocol, name, description) VALUES('729', '17', 'netviewdm1', 'IBM NetView DM/6000 Server/Client');
INSERT INTO services(port, protocol, name, description) VALUES('730', '6', 'netviewdm2', 'IBM NetView DM/6000 send/tcp');
INSERT INTO services(port, protocol, name, description) VALUES('730', '17', 'netviewdm2', 'IBM NetView DM/6000 send/tcp');
INSERT INTO services(port, protocol, name, description) VALUES('731', '6', 'netviewdm3', 'IBM NetView DM/6000 receive/tcp');
INSERT INTO services(port, protocol, name, description) VALUES('731', '17', 'netviewdm3', 'IBM NetView DM/6000 receive/tcp');
INSERT INTO services(port, protocol, name, description) VALUES('732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('741', '6', 'netgw', 'netGW');
INSERT INTO services(port, protocol, name, description) VALUES('741', '17', 'netgw', 'netGW');
INSERT INTO services(port, protocol, name, description) VALUES('742', '6', 'netrcs', 'Network based Rev. Cont. Sys.');
INSERT INTO services(port, protocol, name, description) VALUES('742', '17', 'netrcs', 'Network based Rev. Cont. Sys.');
INSERT INTO services(port, protocol, name, description) VALUES('743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('744', '6', 'flexlm', 'Flexible License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('744', '17', 'flexlm', 'Flexible License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('747', '6', 'fujitsu-dev', 'Fujitsu Device Control');
INSERT INTO services(port, protocol, name, description) VALUES('747', '17', 'fujitsu-dev', 'Fujitsu Device Control');
INSERT INTO services(port, protocol, name, description) VALUES('748', '6', 'ris-cm', 'Russell Info Sci Calendar Manager');
INSERT INTO services(port, protocol, name, description) VALUES('748', '17', 'ris-cm', 'Russell Info Sci Calendar Manager');
INSERT INTO services(port, protocol, name, description) VALUES('749', '6', 'kerberos-adm', 'kerberos administration');
INSERT INTO services(port, protocol, name, description) VALUES('749', '17', 'kerberos-adm', 'kerberos administration');
INSERT INTO services(port, protocol, name, description) VALUES('750', '6', 'rfile', '');
INSERT INTO services(port, protocol, name, description) VALUES('750', '17', 'loadav', '');
INSERT INTO services(port, protocol, name, description) VALUES('751', '6', 'pump', '');
INSERT INTO services(port, protocol, name, description) VALUES('751', '17', 'pump', '');
INSERT INTO services(port, protocol, name, description) VALUES('752', '6', 'qrh', '');
INSERT INTO services(port, protocol, name, description) VALUES('752', '17', 'qrh', '');
INSERT INTO services(port, protocol, name, description) VALUES('753', '6', 'rrh', '');
INSERT INTO services(port, protocol, name, description) VALUES('753', '17', 'rrh', '');
INSERT INTO services(port, protocol, name, description) VALUES('754', '6', 'tell', 'send');
INSERT INTO services(port, protocol, name, description) VALUES('754', '17', 'tell', 'send');
INSERT INTO services(port, protocol, name, description) VALUES('755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('758', '6', 'nlogin', '');
INSERT INTO services(port, protocol, name, description) VALUES('758', '17', 'nlogin', '');
INSERT INTO services(port, protocol, name, description) VALUES('759', '6', 'con', '');
INSERT INTO services(port, protocol, name, description) VALUES('759', '17', 'con', '');
INSERT INTO services(port, protocol, name, description) VALUES('760', '6', 'ns', '');
INSERT INTO services(port, protocol, name, description) VALUES('760', '17', 'ns', '');
INSERT INTO services(port, protocol, name, description) VALUES('761', '6', 'rxe', '');
INSERT INTO services(port, protocol, name, description) VALUES('761', '17', 'rxe', '');
INSERT INTO services(port, protocol, name, description) VALUES('762', '6', 'quotad', '');
INSERT INTO services(port, protocol, name, description) VALUES('762', '17', 'quotad', '');
INSERT INTO services(port, protocol, name, description) VALUES('763', '6', 'cycleserv', '');
INSERT INTO services(port, protocol, name, description) VALUES('763', '17', 'cycleserv', '');
INSERT INTO services(port, protocol, name, description) VALUES('764', '6', 'omserv', '');
INSERT INTO services(port, protocol, name, description) VALUES('764', '17', 'omserv', '');
INSERT INTO services(port, protocol, name, description) VALUES('765', '6', 'webster', '');
INSERT INTO services(port, protocol, name, description) VALUES('765', '17', 'webster', '');
INSERT INTO services(port, protocol, name, description) VALUES('766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('767', '6', 'phonebook', 'phone');
INSERT INTO services(port, protocol, name, description) VALUES('767', '17', 'phonebook', 'phone');
INSERT INTO services(port, protocol, name, description) VALUES('768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('769', '6', 'vid', '');
INSERT INTO services(port, protocol, name, description) VALUES('769', '17', 'vid', '');
INSERT INTO services(port, protocol, name, description) VALUES('770', '6', 'cadlock', '');
INSERT INTO services(port, protocol, name, description) VALUES('770', '17', 'cadlock', '');
INSERT INTO services(port, protocol, name, description) VALUES('771', '6', 'rtip', '');
INSERT INTO services(port, protocol, name, description) VALUES('771', '17', 'rtip', '');
INSERT INTO services(port, protocol, name, description) VALUES('772', '6', 'cycleserv2', '');
INSERT INTO services(port, protocol, name, description) VALUES('772', '17', 'cycleserv2', '');
INSERT INTO services(port, protocol, name, description) VALUES('773', '6', 'submit', '');
INSERT INTO services(port, protocol, name, description) VALUES('773', '17', 'notify', '');
INSERT INTO services(port, protocol, name, description) VALUES('774', '6', 'rpasswd', '');
INSERT INTO services(port, protocol, name, description) VALUES('774', '17', 'acmaint_dbd', '');
INSERT INTO services(port, protocol, name, description) VALUES('775', '6', 'entomb', '');
INSERT INTO services(port, protocol, name, description) VALUES('775', '17', 'acmaint_transd', '');
INSERT INTO services(port, protocol, name, description) VALUES('776', '6', 'wpages', '');
INSERT INTO services(port, protocol, name, description) VALUES('776', '17', 'wpages', '');
INSERT INTO services(port, protocol, name, description) VALUES('777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('780', '6', 'wpgs', '');
INSERT INTO services(port, protocol, name, description) VALUES('780', '17', 'wpgs', '');
INSERT INTO services(port, protocol, name, description) VALUES('781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('786', '6', 'concert', 'Concert');
INSERT INTO services(port, protocol, name, description) VALUES('786', '17', 'concert', 'Concert');
INSERT INTO services(port, protocol, name, description) VALUES('787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('800', '6', 'mdbs_daemon', '');
INSERT INTO services(port, protocol, name, description) VALUES('800', '17', 'mdbs_daemon', '');
INSERT INTO services(port, protocol, name, description) VALUES('801', '6', 'device', '');
INSERT INTO services(port, protocol, name, description) VALUES('801', '17', 'device', '');
INSERT INTO services(port, protocol, name, description) VALUES('802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('996', '6', 'xtreelic', 'Central Point Software');
INSERT INTO services(port, protocol, name, description) VALUES('996', '17', 'xtreelic', 'Central Point Software');
INSERT INTO services(port, protocol, name, description) VALUES('997', '6', 'maitrd', '');
INSERT INTO services(port, protocol, name, description) VALUES('997', '17', 'maitrd', '');
INSERT INTO services(port, protocol, name, description) VALUES('998', '6', 'busboy', '');
INSERT INTO services(port, protocol, name, description) VALUES('998', '17', 'puparp', '');
INSERT INTO services(port, protocol, name, description) VALUES('999', '6', 'puprouter', '');
INSERT INTO services(port, protocol, name, description) VALUES('999', '17', 'puprouter', '');
INSERT INTO services(port, protocol, name, description) VALUES('1000', '6', 'cadlock', '');
INSERT INTO services(port, protocol, name, description) VALUES('1000', '17', 'ock', '');
INSERT INTO services(port, protocol, name, description) VALUES('1001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1025', '6', 'blackjack', 'network blackjack');
INSERT INTO services(port, protocol, name, description) VALUES('1025', '17', 'blackjack', 'network blackjack');
INSERT INTO services(port, protocol, name, description) VALUES('1026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1030', '6', 'iad1', 'BBN IAD');
INSERT INTO services(port, protocol, name, description) VALUES('1030', '17', 'iad1', 'BBN IAD');
INSERT INTO services(port, protocol, name, description) VALUES('1031', '6', 'iad2', 'BBN IAD');
INSERT INTO services(port, protocol, name, description) VALUES('1031', '17', 'iad2', 'BBN IAD');
INSERT INTO services(port, protocol, name, description) VALUES('1032', '6', 'iad3', 'BBN IAD');
INSERT INTO services(port, protocol, name, description) VALUES('1032', '17', 'iad3', 'BBN IAD');
INSERT INTO services(port, protocol, name, description) VALUES('1033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1067', '6', 'instl_boots', 'Installation Bootstrap Proto. Serv.');
INSERT INTO services(port, protocol, name, description) VALUES('1067', '17', 'instl_boots', 'Installation Bootstrap Proto. Serv.');
INSERT INTO services(port, protocol, name, description) VALUES('1068', '6', 'instl_bootc', 'Installation Bootstrap Proto. Cli.');
INSERT INTO services(port, protocol, name, description) VALUES('1068', '17', 'instl_bootc', 'Installation Bootstrap Proto. Cli.');
INSERT INTO services(port, protocol, name, description) VALUES('1069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1080', '6', 'socks', 'Socks');
INSERT INTO services(port, protocol, name, description) VALUES('1080', '17', 'socks', 'Socks');
INSERT INTO services(port, protocol, name, description) VALUES('1081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1083', '6', 'ansoft-lm-1', 'Anasoft License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1083', '17', 'ansoft-lm-1', 'Anasoft License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1084', '6', 'ansoft-lm-2', 'Anasoft License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1084', '17', 'ansoft-lm-2', 'Anasoft License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1155', '6', 'nfa', 'Network File Access');
INSERT INTO services(port, protocol, name, description) VALUES('1155', '17', 'nfa', 'Network File Access');
INSERT INTO services(port, protocol, name, description) VALUES('1156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1222', '6', 'nerv', 'SNI R&D network');
INSERT INTO services(port, protocol, name, description) VALUES('1222', '17', 'nerv', 'SNI R&D network');
INSERT INTO services(port, protocol, name, description) VALUES('1223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1248', '6', 'hermes', '');
INSERT INTO services(port, protocol, name, description) VALUES('1248', '17', 'hermes', '');
INSERT INTO services(port, protocol, name, description) VALUES('1249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1346', '6', 'alta-ana-lm', 'Alta Analytics License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1346', '17', 'alta-ana-lm', 'Alta Analytics License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1347', '6', 'bbn-mmc', 'multi media conferencing');
INSERT INTO services(port, protocol, name, description) VALUES('1347', '17', 'bbn-mmc', 'multi media conferencing');
INSERT INTO services(port, protocol, name, description) VALUES('1348', '6', 'bbn-mmx', 'multi media conferencing');
INSERT INTO services(port, protocol, name, description) VALUES('1348', '17', 'bbn-mmx', 'multi media conferencing');
INSERT INTO services(port, protocol, name, description) VALUES('1349', '6', 'sbook', 'Registration Network Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('1349', '17', 'sbook', 'Registration Network Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('1350', '6', 'editbench', 'Registration Network Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('1350', '17', 'editbench', 'Registration Network Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('1351', '6', 'equationbuilder', 'Digital Tool Works (MIT)');
INSERT INTO services(port, protocol, name, description) VALUES('1351', '17', 'equationbuilder', 'Digital Tool Works (MIT)');
INSERT INTO services(port, protocol, name, description) VALUES('1352', '6', 'lotusnote', 'Lotus Note');
INSERT INTO services(port, protocol, name, description) VALUES('1352', '17', 'lotusnote', 'Lotus Note');
INSERT INTO services(port, protocol, name, description) VALUES('1353', '6', 'relief', 'Relief Consulting');
INSERT INTO services(port, protocol, name, description) VALUES('1353', '17', 'relief', 'Relief Consulting');
INSERT INTO services(port, protocol, name, description) VALUES('1354', '6', 'rightbrain', 'RightBrain Software');
INSERT INTO services(port, protocol, name, description) VALUES('1354', '17', 'rightbrain', 'RightBrain Software');
INSERT INTO services(port, protocol, name, description) VALUES('1355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1356', '6', 'cuillamartin', 'CuillaMartin Company');
INSERT INTO services(port, protocol, name, description) VALUES('1356', '17', 'cuillamartin', 'CuillaMartin Company');
INSERT INTO services(port, protocol, name, description) VALUES('1357', '6', 'pegboard', 'Electronic PegBoard');
INSERT INTO services(port, protocol, name, description) VALUES('1357', '17', 'pegboard', 'Electronic PegBoard');
INSERT INTO services(port, protocol, name, description) VALUES('1358', '6', 'connlcli', 'CONNLCLI');
INSERT INTO services(port, protocol, name, description) VALUES('1358', '17', 'connlcli', 'CONNLCLI');
INSERT INTO services(port, protocol, name, description) VALUES('1359', '6', 'ftsrv', 'FTSRV');
INSERT INTO services(port, protocol, name, description) VALUES('1359', '17', 'ftsrv', 'FTSRV');
INSERT INTO services(port, protocol, name, description) VALUES('1360', '6', 'mimer', 'MIMER');
INSERT INTO services(port, protocol, name, description) VALUES('1360', '17', 'mimer', 'MIMER');
INSERT INTO services(port, protocol, name, description) VALUES('1361', '6', 'linx', 'LinX');
INSERT INTO services(port, protocol, name, description) VALUES('1361', '17', 'linx', 'LinX');
INSERT INTO services(port, protocol, name, description) VALUES('1362', '6', 'timeflies', 'TimeFlies');
INSERT INTO services(port, protocol, name, description) VALUES('1362', '17', 'timeflies', 'TimeFlies');
INSERT INTO services(port, protocol, name, description) VALUES('1363', '6', 'ndm-requester', 'Network DataMover Requester');
INSERT INTO services(port, protocol, name, description) VALUES('1363', '17', 'ndm-requester', 'Network DataMover Requester');
INSERT INTO services(port, protocol, name, description) VALUES('1364', '6', 'ndm-server', 'Network DataMover Server');
INSERT INTO services(port, protocol, name, description) VALUES('1364', '17', 'ndm-server', 'Network DataMover Server');
INSERT INTO services(port, protocol, name, description) VALUES('1365', '6', 'adapt-sna', 'Network Software Associates');
INSERT INTO services(port, protocol, name, description) VALUES('1365', '17', 'adapt-sna', 'Network Software Associates');
INSERT INTO services(port, protocol, name, description) VALUES('1366', '6', 'netware-csp', 'Novell NetWare Comm Service Platform');
INSERT INTO services(port, protocol, name, description) VALUES('1366', '17', 'netware-csp', 'Novell NetWare Comm Service Platform');
INSERT INTO services(port, protocol, name, description) VALUES('1367', '6', 'dcs', 'DCS');
INSERT INTO services(port, protocol, name, description) VALUES('1367', '17', 'dcs', 'DCS');
INSERT INTO services(port, protocol, name, description) VALUES('1368', '6', 'screencast', 'ScreenCast');
INSERT INTO services(port, protocol, name, description) VALUES('1368', '17', 'screencast', 'ScreenCast');
INSERT INTO services(port, protocol, name, description) VALUES('1369', '6', 'gv-us', 'GlobalView to Unix Shell');
INSERT INTO services(port, protocol, name, description) VALUES('1369', '17', 'gv-us', 'GlobalView to Unix Shell');
INSERT INTO services(port, protocol, name, description) VALUES('1370', '6', 'us-gv', 'Unix Shell to GlobalView');
INSERT INTO services(port, protocol, name, description) VALUES('1370', '17', 'us-gv', 'Unix Shell to GlobalView');
INSERT INTO services(port, protocol, name, description) VALUES('1371', '6', 'fc-cli', 'Fujitsu Config Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('1371', '17', 'fc-cli', 'Fujitsu Config Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('1372', '6', 'fc-ser', 'Fujitsu Config Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('1372', '17', 'fc-ser', 'Fujitsu Config Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('1373', '6', 'chromagrafx', 'Chromagrafx');
INSERT INTO services(port, protocol, name, description) VALUES('1373', '17', 'chromagrafx', 'Chromagrafx');
INSERT INTO services(port, protocol, name, description) VALUES('1374', '6', 'molly', 'EPI Software Systems');
INSERT INTO services(port, protocol, name, description) VALUES('1374', '17', 'molly', 'EPI Software Systems');
INSERT INTO services(port, protocol, name, description) VALUES('1375', '6', 'bytex', 'Bytex');
INSERT INTO services(port, protocol, name, description) VALUES('1375', '17', 'bytex', 'Bytex');
INSERT INTO services(port, protocol, name, description) VALUES('1376', '6', 'ibm-pps', 'IBM Person to Person Software');
INSERT INTO services(port, protocol, name, description) VALUES('1376', '17', 'ibm-pps', 'IBM Person to Person Software');
INSERT INTO services(port, protocol, name, description) VALUES('1377', '6', 'cichlid', 'Cichlid License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1377', '17', 'cichlid', 'Cichlid License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1378', '6', 'elan', 'Elan License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1378', '17', 'elan', 'Elan License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1379', '6', 'dbreporter', 'Integrity Solutions');
INSERT INTO services(port, protocol, name, description) VALUES('1379', '17', 'dbreporter', 'Integrity Solutions');
INSERT INTO services(port, protocol, name, description) VALUES('1380', '6', 'telesis-licman', 'Telesis Network License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1380', '17', 'telesis-licman', 'Telesis Network License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1381', '6', 'apple-licman', 'Apple Network License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1381', '17', 'apple-licman', 'Apple Network License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1382', '6', 'udt_os', '');
INSERT INTO services(port, protocol, name, description) VALUES('1382', '17', 'udt_os', '');
INSERT INTO services(port, protocol, name, description) VALUES('1383', '6', 'gwha', 'GW Hannaway Network License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1383', '17', 'gwha', 'GW Hannaway Network License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1384', '6', 'os-licman', 'Objective Solutions License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1384', '17', 'os-licman', 'Objective Solutions License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1385', '6', 'atex_elmd', 'Atex Publishing License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1385', '17', 'atex_elmd', 'Atex Publishing License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1386', '6', 'checksum', 'CheckSum License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1386', '17', 'checksum', 'CheckSum License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1387', '6', 'cadsi-lm', 'Computer Aided Design Software Inc LM');
INSERT INTO services(port, protocol, name, description) VALUES('1387', '17', 'cadsi-lm', 'Computer Aided Design Software Inc LM');
INSERT INTO services(port, protocol, name, description) VALUES('1388', '6', 'objective-dbc', 'Objective Solutions DataBase Cache');
INSERT INTO services(port, protocol, name, description) VALUES('1388', '17', 'objective-dbc', 'Objective Solutions DataBase Cache');
INSERT INTO services(port, protocol, name, description) VALUES('1389', '6', 'iclpv-dm', 'Document Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1389', '17', 'iclpv-dm', 'Document Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1390', '6', 'iclpv-sc', 'Storage Controller');
INSERT INTO services(port, protocol, name, description) VALUES('1390', '17', 'iclpv-sc', 'Storage Controller');
INSERT INTO services(port, protocol, name, description) VALUES('1391', '6', 'iclpv-sas', 'Storage Access Server');
INSERT INTO services(port, protocol, name, description) VALUES('1391', '17', 'iclpv-sas', 'Storage Access Server');
INSERT INTO services(port, protocol, name, description) VALUES('1392', '6', 'iclpv-pm', 'Print Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1392', '17', 'iclpv-pm', 'Print Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1393', '6', 'iclpv-nls', 'Network Log Server');
INSERT INTO services(port, protocol, name, description) VALUES('1393', '17', 'iclpv-nls', 'Network Log Server');
INSERT INTO services(port, protocol, name, description) VALUES('1394', '6', 'iclpv-nlc', 'Network Log Client');
INSERT INTO services(port, protocol, name, description) VALUES('1394', '17', 'iclpv-nlc', 'Network Log Client');
INSERT INTO services(port, protocol, name, description) VALUES('1395', '6', 'iclpv-wsm', 'PC Workstation Manager software');
INSERT INTO services(port, protocol, name, description) VALUES('1395', '17', 'iclpv-wsm', 'PC Workstation Manager software');
INSERT INTO services(port, protocol, name, description) VALUES('1396', '6', 'dvl-activemail', 'DVL Active Mail');
INSERT INTO services(port, protocol, name, description) VALUES('1396', '17', 'dvl-activemail', 'DVL Active Mail');
INSERT INTO services(port, protocol, name, description) VALUES('1397', '6', 'audio-activmail', 'Audio Active Mail');
INSERT INTO services(port, protocol, name, description) VALUES('1397', '17', 'audio-activmail', 'Audio Active Mail');
INSERT INTO services(port, protocol, name, description) VALUES('1398', '6', 'video-activmail', 'Video Active Mail');
INSERT INTO services(port, protocol, name, description) VALUES('1398', '17', 'video-activmail', 'Video Active Mail');
INSERT INTO services(port, protocol, name, description) VALUES('1399', '6', 'cadkey-licman', 'Cadkey License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1399', '17', 'cadkey-licman', 'Cadkey License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1400', '6', 'cadkey-tablet', 'Cadkey Tablet Daemon');
INSERT INTO services(port, protocol, name, description) VALUES('1400', '17', 'cadkey-tablet', 'Cadkey Tablet Daemon');
INSERT INTO services(port, protocol, name, description) VALUES('1401', '6', 'goldleaf-licman', 'Goldleaf License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1401', '17', 'goldleaf-licman', 'Goldleaf License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1402', '6', 'prm-sm-np', 'Prospero Resource Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1402', '17', 'prm-sm-np', 'Prospero Resource Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1403', '6', 'prm-nm-np', 'Prospero Resource Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1403', '17', 'prm-nm-np', 'Prospero Resource Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1404', '6', 'igi-lm', 'Infinite Graphics License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1404', '17', 'igi-lm', 'Infinite Graphics License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1405', '6', 'ibm-res', 'IBM Remote Execution Starter');
INSERT INTO services(port, protocol, name, description) VALUES('1405', '17', 'ibm-res', 'IBM Remote Execution Starter');
INSERT INTO services(port, protocol, name, description) VALUES('1406', '6', 'netlabs-lm', 'NetLabs License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1406', '17', 'netlabs-lm', 'NetLabs License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1407', '6', 'dbsa-lm', 'DBSA License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1407', '17', 'dbsa-lm', 'DBSA License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1408', '6', 'sophia-lm', 'Sophia License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1408', '17', 'sophia-lm', 'Sophia License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1409', '6', 'here-lm', 'Here License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1409', '17', 'here-lm', 'Here License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1410', '6', 'hiq', 'HiQ License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1410', '17', 'hiq', 'HiQ License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1411', '6', 'af', 'AudioFile');
INSERT INTO services(port, protocol, name, description) VALUES('1411', '17', 'af', 'AudioFile');
INSERT INTO services(port, protocol, name, description) VALUES('1412', '6', 'innosys', 'InnoSys');
INSERT INTO services(port, protocol, name, description) VALUES('1412', '17', 'innosys', 'InnoSys');
INSERT INTO services(port, protocol, name, description) VALUES('1413', '6', 'innosys-acl', 'Innosys-ACL');
INSERT INTO services(port, protocol, name, description) VALUES('1413', '17', 'innosys-acl', 'Innosys-ACL');
INSERT INTO services(port, protocol, name, description) VALUES('1414', '6', 'ibm-mqseries', 'IBM MQSeries');
INSERT INTO services(port, protocol, name, description) VALUES('1414', '17', 'ibm-mqseries', 'IBM MQSeries');
INSERT INTO services(port, protocol, name, description) VALUES('1415', '6', 'dbstar', 'DBStar');
INSERT INTO services(port, protocol, name, description) VALUES('1415', '17', 'dbstar', 'DBStar');
INSERT INTO services(port, protocol, name, description) VALUES('1416', '6', 'novell-lu6.2', 'Novell LU6.2');
INSERT INTO services(port, protocol, name, description) VALUES('1416', '17', 'novell-lu6.2', 'Novell LU6.2');
INSERT INTO services(port, protocol, name, description) VALUES('1417', '6', 'timbuktu-srv1', 'Timbuktu Service 1 Port');
INSERT INTO services(port, protocol, name, description) VALUES('1417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1418', '6', 'timbuktu-srv2', 'Timbuktu Service 2 Port');
INSERT INTO services(port, protocol, name, description) VALUES('1418', '17', 'timbuktu-srv2', 'Timbuktu Service 2 Port');
INSERT INTO services(port, protocol, name, description) VALUES('1419', '6', 'timbuktu-srv3', 'Timbuktu Service 3 Port');
INSERT INTO services(port, protocol, name, description) VALUES('1419', '17', 'timbuktu-srv3', 'Timbuktu Service 3 Port');
INSERT INTO services(port, protocol, name, description) VALUES('1420', '6', 'timbuktu-srv4', 'Timbuktu Service 4 Port');
INSERT INTO services(port, protocol, name, description) VALUES('1420', '17', 'timbuktu-srv4', 'Timbuktu Service 4 Port');
INSERT INTO services(port, protocol, name, description) VALUES('1421', '6', 'gandalf-lm', 'Gandalf License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1421', '17', 'gandalf-lm', 'Gandalf License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1422', '6', 'autodesk-lm', 'Autodesk License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1422', '17', 'autodesk-lm', 'Autodesk License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1423', '6', 'essbase', 'Essbase Arbor Software');
INSERT INTO services(port, protocol, name, description) VALUES('1423', '17', 'essbase', 'Essbase Arbor Software');
INSERT INTO services(port, protocol, name, description) VALUES('1424', '6', 'hybrid', 'Hybrid Encryption Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('1424', '17', 'hybrid', 'Hybrid Encryption Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('1425', '6', 'zion-lm', 'Zion Software License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1425', '17', 'zion-lm', 'Zion Software License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1426', '6', 'sas-1', 'Satellite-data Acquisition System 1');
INSERT INTO services(port, protocol, name, description) VALUES('1426', '17', 'sas-1', 'Satellite-data Acquisition System 1');
INSERT INTO services(port, protocol, name, description) VALUES('1427', '6', 'mloadd', 'mloadd monitoring tool');
INSERT INTO services(port, protocol, name, description) VALUES('1427', '17', 'mloadd', 'mloadd monitoring tool');
INSERT INTO services(port, protocol, name, description) VALUES('1428', '6', 'informatik-lm', 'Informatik License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1428', '17', 'informatik-lm', 'Informatik License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1429', '6', 'nms', 'Hypercom NMS');
INSERT INTO services(port, protocol, name, description) VALUES('1429', '17', 'nms', 'Hypercom NMS');
INSERT INTO services(port, protocol, name, description) VALUES('1430', '6', 'tpdu', 'Hypercom TPDU');
INSERT INTO services(port, protocol, name, description) VALUES('1430', '17', 'tpdu', 'Hypercom TPDU');
INSERT INTO services(port, protocol, name, description) VALUES('1431', '6', 'rgtp', 'Reverse Gosip Transport');
INSERT INTO services(port, protocol, name, description) VALUES('1431', '17', 'rgtp', 'Reverse Gosip Transport');
INSERT INTO services(port, protocol, name, description) VALUES('1432', '6', 'blueberry-lm', 'Blueberry Software License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1432', '17', 'blueberry-lm', 'Blueberry Software License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1433', '6', 'ms-sql-s', 'Microsoft-SQL-Server');
INSERT INTO services(port, protocol, name, description) VALUES('1433', '17', 'ms-sql-s', 'Microsoft-SQL-Server');
INSERT INTO services(port, protocol, name, description) VALUES('1434', '6', 'ms-sql-m', 'Microsoft-SQL-Monitor');
INSERT INTO services(port, protocol, name, description) VALUES('1434', '17', 'ms-sql-m', 'Microsoft-SQL-Monitor');
INSERT INTO services(port, protocol, name, description) VALUES('1435', '6', 'ibm-cics', 'IBM CISC');
INSERT INTO services(port, protocol, name, description) VALUES('1435', '17', 'ibm-cics', 'IBM CISC');
INSERT INTO services(port, protocol, name, description) VALUES('1436', '6', 'sas-2', 'Satellite-data Acquisition System 2');
INSERT INTO services(port, protocol, name, description) VALUES('1436', '17', 'sas-2', 'Satellite-data Acquisition System 2');
INSERT INTO services(port, protocol, name, description) VALUES('1437', '6', 'tabula', 'Tabula');
INSERT INTO services(port, protocol, name, description) VALUES('1437', '17', 'tabula', 'Tabula');
INSERT INTO services(port, protocol, name, description) VALUES('1438', '6', 'eicon-server', 'Eicon Security Agent/Server');
INSERT INTO services(port, protocol, name, description) VALUES('1438', '17', 'eicon-server', 'Eicon Security Agent/Server');
INSERT INTO services(port, protocol, name, description) VALUES('1439', '6', 'eicon-x25', 'Eicon X25/SNA Gateway');
INSERT INTO services(port, protocol, name, description) VALUES('1439', '17', 'eicon-x25', 'Eicon X25/SNA Gateway');
INSERT INTO services(port, protocol, name, description) VALUES('1440', '6', 'eicon-slp', 'Eicon Service Location Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('1440', '17', 'eicon-slp', 'Eicon Service Location Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('1441', '6', 'cadis-1', 'Cadis License Management');
INSERT INTO services(port, protocol, name, description) VALUES('1441', '17', 'cadis-1', 'Cadis License Management');
INSERT INTO services(port, protocol, name, description) VALUES('1442', '6', 'cadis-2', 'Cadis License Management');
INSERT INTO services(port, protocol, name, description) VALUES('1442', '17', 'cadis-2', 'Cadis License Management');
INSERT INTO services(port, protocol, name, description) VALUES('1443', '6', 'ies-lm', 'Integrated Engineering Software');
INSERT INTO services(port, protocol, name, description) VALUES('1443', '17', 'ies-lm', 'Integrated Engineering Software');
INSERT INTO services(port, protocol, name, description) VALUES('1444', '6', 'marcam-lm', 'Marcam  License Management');
INSERT INTO services(port, protocol, name, description) VALUES('1444', '17', 'marcam-lm', 'Marcam  License Management');
INSERT INTO services(port, protocol, name, description) VALUES('1445', '6', 'proxima-lm', 'Proxima License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1445', '17', 'proxima-lm', 'Proxima License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1446', '6', 'ora-lm', 'Optical Research Associates License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1446', '17', 'ora-lm', 'Optical Research Associates License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1447', '6', 'apri-lm', 'Applied Parallel Research LM');
INSERT INTO services(port, protocol, name, description) VALUES('1447', '17', 'apri-lm', 'Applied Parallel Research LM');
INSERT INTO services(port, protocol, name, description) VALUES('1448', '6', 'oc-lm', 'OpenConnect License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1448', '17', 'oc-lm', 'OpenConnect License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1449', '6', 'peport', 'PEport');
INSERT INTO services(port, protocol, name, description) VALUES('1449', '17', 'peport', 'PEport');
INSERT INTO services(port, protocol, name, description) VALUES('1450', '6', 'dwf', 'Tandem Distributed Workbench Facility');
INSERT INTO services(port, protocol, name, description) VALUES('1450', '17', 'dwf', 'Tandem Distributed Workbench Facility');
INSERT INTO services(port, protocol, name, description) VALUES('1451', '6', 'infoman', 'IBM Information Management');
INSERT INTO services(port, protocol, name, description) VALUES('1451', '17', 'infoman', 'IBM Information Management');
INSERT INTO services(port, protocol, name, description) VALUES('1452', '6', 'gtegsc-lm', 'GTE Government Systems License Man');
INSERT INTO services(port, protocol, name, description) VALUES('1452', '17', 'gtegsc-lm', 'GTE Government Systems License Man');
INSERT INTO services(port, protocol, name, description) VALUES('1453', '6', 'genie-lm', 'Genie License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1453', '17', 'genie-lm', 'Genie License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1454', '6', 'interhdl_elmd', 'interHDL License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1455', '6', 'esl-lm', 'ESL License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1455', '17', 'esl-lm', 'ESL License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1456', '6', 'dca', 'DCA');
INSERT INTO services(port, protocol, name, description) VALUES('1456', '17', 'dca', 'DCA');
INSERT INTO services(port, protocol, name, description) VALUES('1457', '6', 'valisys-lm', 'Valisys License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1457', '17', 'valisys-lm', 'Valisys License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1458', '6', 'nrcabq-lm', 'Nichols Research Corp.');
INSERT INTO services(port, protocol, name, description) VALUES('1458', '17', 'nrcabq-lm', 'Nichols Research Corp.');
INSERT INTO services(port, protocol, name, description) VALUES('1459', '6', 'proshare1', 'Proshare Notebook Application');
INSERT INTO services(port, protocol, name, description) VALUES('1459', '17', 'proshare1', 'Proshare Notebook Application');
INSERT INTO services(port, protocol, name, description) VALUES('1460', '6', 'proshare2', 'Proshare Notebook Application');
INSERT INTO services(port, protocol, name, description) VALUES('1460', '17', 'proshare2', 'Proshare Notebook Application');
INSERT INTO services(port, protocol, name, description) VALUES('1461', '6', 'ibm_wrless_lan', 'IBM Wireless LAN');
INSERT INTO services(port, protocol, name, description) VALUES('1461', '17', 'ibm_wrless_lan', 'IBM Wireless LAN');
INSERT INTO services(port, protocol, name, description) VALUES('1462', '6', 'world-lm', 'World License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1462', '17', 'world-lm', 'World License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1463', '6', 'nucleus', 'Nucleus');
INSERT INTO services(port, protocol, name, description) VALUES('1463', '17', 'nucleus', 'Nucleus');
INSERT INTO services(port, protocol, name, description) VALUES('1464', '6', 'msl_lmd', 'MSL License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1464', '17', 'msl_lmd', 'MSL License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1465', '6', 'pipes', 'Pipes Platform');
INSERT INTO services(port, protocol, name, description) VALUES('1465', '17', 'pipes', 'Pipes Platform  mfarlin@peerlogic.com');
INSERT INTO services(port, protocol, name, description) VALUES('1466', '6', 'oceansoft-lm', 'Ocean Software License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1466', '17', 'oceansoft-lm', 'Ocean Software License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1467', '6', 'csdmbase', 'CSDMBASE');
INSERT INTO services(port, protocol, name, description) VALUES('1467', '17', 'csdmbase', 'CSDMBASE');
INSERT INTO services(port, protocol, name, description) VALUES('1468', '6', 'csdm', 'CSDM');
INSERT INTO services(port, protocol, name, description) VALUES('1468', '17', 'csdm', 'CSDM');
INSERT INTO services(port, protocol, name, description) VALUES('1469', '6', 'aal-lm', 'Active Analysis Limited License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1469', '17', 'aal-lm', 'Active Analysis Limited License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1470', '6', 'uaiact', 'Universal Analytics');
INSERT INTO services(port, protocol, name, description) VALUES('1470', '17', 'uaiact', 'Universal Analytics');
INSERT INTO services(port, protocol, name, description) VALUES('1471', '6', 'csdmbase', 'csdmbase');
INSERT INTO services(port, protocol, name, description) VALUES('1471', '17', 'csdmbase', 'csdmbase');
INSERT INTO services(port, protocol, name, description) VALUES('1472', '6', 'csdm', 'csdm');
INSERT INTO services(port, protocol, name, description) VALUES('1472', '17', 'csdm', 'csdm');
INSERT INTO services(port, protocol, name, description) VALUES('1473', '6', 'openmath', 'OpenMath');
INSERT INTO services(port, protocol, name, description) VALUES('1473', '17', 'openmath', 'OpenMath');
INSERT INTO services(port, protocol, name, description) VALUES('1474', '6', 'telefinder', 'Telefinder');
INSERT INTO services(port, protocol, name, description) VALUES('1474', '17', 'telefinder', 'Telefinder');
INSERT INTO services(port, protocol, name, description) VALUES('1475', '6', 'taligent-lm', 'Taligent License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1475', '17', 'taligent-lm', 'Taligent License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1476', '6', 'clvm-cfg', 'clvm-cfg');
INSERT INTO services(port, protocol, name, description) VALUES('1476', '17', 'clvm-cfg', 'clvm-cfg');
INSERT INTO services(port, protocol, name, description) VALUES('1477', '6', 'ms-sna-server', 'ms-sna-server');
INSERT INTO services(port, protocol, name, description) VALUES('1477', '17', 'ms-sna-server', 'ms-sna-server');
INSERT INTO services(port, protocol, name, description) VALUES('1478', '6', 'ms-sna-base', 'ms-sna-base');
INSERT INTO services(port, protocol, name, description) VALUES('1478', '17', 'ms-sna-base', 'ms-sna-base');
INSERT INTO services(port, protocol, name, description) VALUES('1479', '6', 'dberegister', 'dberegister');
INSERT INTO services(port, protocol, name, description) VALUES('1479', '17', 'dberegister', 'dberegister');
INSERT INTO services(port, protocol, name, description) VALUES('1480', '6', 'pacerforum', 'PacerForum');
INSERT INTO services(port, protocol, name, description) VALUES('1480', '17', 'pacerforum', 'PacerForum');
INSERT INTO services(port, protocol, name, description) VALUES('1481', '6', 'airs', 'AIRS');
INSERT INTO services(port, protocol, name, description) VALUES('1481', '17', 'airs', 'AIRS');
INSERT INTO services(port, protocol, name, description) VALUES('1482', '6', 'miteksys-lm', 'Miteksys License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1482', '17', 'miteksys-lm', 'Miteksys License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1483', '6', 'afs', 'AFS License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1483', '17', 'afs', 'AFS License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1484', '6', 'confluent', 'Confluent License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1484', '17', 'confluent', 'Confluent License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1485', '6', 'lansource', 'LANSource');
INSERT INTO services(port, protocol, name, description) VALUES('1485', '17', 'lansource', 'LANSource');
INSERT INTO services(port, protocol, name, description) VALUES('1486', '6', 'nms_topo_serv', 'nms_topo_serv');
INSERT INTO services(port, protocol, name, description) VALUES('1486', '17', 'nms_topo_serv', 'nms_topo_serv');
INSERT INTO services(port, protocol, name, description) VALUES('1487', '6', 'localinfosrvr', 'LocalInfoSrvr');
INSERT INTO services(port, protocol, name, description) VALUES('1487', '17', 'localinfosrvr', 'LocalInfoSrvr');
INSERT INTO services(port, protocol, name, description) VALUES('1488', '6', 'docstor', 'DocStor');
INSERT INTO services(port, protocol, name, description) VALUES('1488', '17', 'docstor', 'DocStor');
INSERT INTO services(port, protocol, name, description) VALUES('1489', '6', 'dmdocbroker', 'dmdocbroker');
INSERT INTO services(port, protocol, name, description) VALUES('1489', '17', 'dmdocbroker', 'dmdocbroker');
INSERT INTO services(port, protocol, name, description) VALUES('1490', '6', 'insitu-conf', 'insitu-conf');
INSERT INTO services(port, protocol, name, description) VALUES('1490', '17', 'insitu-conf', 'insitu-conf');
INSERT INTO services(port, protocol, name, description) VALUES('1491', '6', 'anynetgateway', 'anynetgateway');
INSERT INTO services(port, protocol, name, description) VALUES('1491', '17', 'anynetgateway', 'anynetgateway');
INSERT INTO services(port, protocol, name, description) VALUES('1492', '6', 'stone-design-1', 'stone-design-1');
INSERT INTO services(port, protocol, name, description) VALUES('1492', '17', 'stone-design-1', 'stone-design-1');
INSERT INTO services(port, protocol, name, description) VALUES('1493', '6', 'netmap_lm', 'netmap_lm');
INSERT INTO services(port, protocol, name, description) VALUES('1493', '17', 'netmap_lm', 'netmap_lm');
INSERT INTO services(port, protocol, name, description) VALUES('1494', '6', 'ica', 'ica');
INSERT INTO services(port, protocol, name, description) VALUES('1494', '17', 'ica', 'ica');
INSERT INTO services(port, protocol, name, description) VALUES('1495', '6', 'cvc', 'cvc');
INSERT INTO services(port, protocol, name, description) VALUES('1495', '17', 'cvc', 'cvc');
INSERT INTO services(port, protocol, name, description) VALUES('1496', '6', 'liberty-lm', 'liberty-lm');
INSERT INTO services(port, protocol, name, description) VALUES('1496', '17', 'liberty-lm', 'liberty-lm');
INSERT INTO services(port, protocol, name, description) VALUES('1497', '6', 'rfx-lm', 'rfx-lm');
INSERT INTO services(port, protocol, name, description) VALUES('1497', '17', 'rfx-lm', 'rfx-lm');
INSERT INTO services(port, protocol, name, description) VALUES('1498', '6', 'watcom-sql', 'Watcom-SQL');
INSERT INTO services(port, protocol, name, description) VALUES('1498', '17', 'watcom-sql', 'Watcom-SQL');
INSERT INTO services(port, protocol, name, description) VALUES('1499', '6', 'fhc', 'Federico Heinz Consultora');
INSERT INTO services(port, protocol, name, description) VALUES('1499', '17', 'fhc', 'Federico Heinz Consultora');
INSERT INTO services(port, protocol, name, description) VALUES('1500', '6', 'vlsi-lm', 'VLSI License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1500', '17', 'vlsi-lm', 'VLSI License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1501', '6', 'sas-3', 'Satellite-data Acquisition System 3');
INSERT INTO services(port, protocol, name, description) VALUES('1501', '17', 'sas-3', 'Satellite-data Acquisition System 3');
INSERT INTO services(port, protocol, name, description) VALUES('1502', '6', 'shivadiscovery', 'Shiva');
INSERT INTO services(port, protocol, name, description) VALUES('1502', '17', 'shivadiscovery', 'Shiva');
INSERT INTO services(port, protocol, name, description) VALUES('1503', '6', 'imtc-mcs', 'Databeam');
INSERT INTO services(port, protocol, name, description) VALUES('1503', '17', 'imtc-mcs', 'Databeam');
INSERT INTO services(port, protocol, name, description) VALUES('1504', '6', 'evb-elm', 'EVB Software Engineering License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1504', '17', 'evb-elm', 'EVB Software Engineering License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('1505', '6', 'funkproxy', 'Funk Software, Inc.');
INSERT INTO services(port, protocol, name, description) VALUES('1505', '17', 'funkproxy', 'Funk Software, Inc.');
INSERT INTO services(port, protocol, name, description) VALUES('1506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1524', '6', 'ingreslock', 'ingres');
INSERT INTO services(port, protocol, name, description) VALUES('1524', '17', 'ingreslock', 'ingres');
INSERT INTO services(port, protocol, name, description) VALUES('1525', '6', 'prospero-np', 'Prospero Directory Service non-priv');
INSERT INTO services(port, protocol, name, description) VALUES('1525', '17', 'prospero-np', 'Prospero Directory Service non-priv');
INSERT INTO services(port, protocol, name, description) VALUES('1526', '6', 'pdap-np', 'Prospero Data Access Prot non-priv');
INSERT INTO services(port, protocol, name, description) VALUES('1526', '17', 'pdap-np', 'Prospero Data Access Prot non-priv');
INSERT INTO services(port, protocol, name, description) VALUES('1527', '6', 'tlisrv', 'oracle');
INSERT INTO services(port, protocol, name, description) VALUES('1527', '17', 'tlisrv', 'oracle');
INSERT INTO services(port, protocol, name, description) VALUES('1528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1529', '6', 'coauthor', 'oracle');
INSERT INTO services(port, protocol, name, description) VALUES('1529', '17', 'coauthor', 'oracle');
INSERT INTO services(port, protocol, name, description) VALUES('1530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1600', '6', 'issd', '');
INSERT INTO services(port, protocol, name, description) VALUES('1600', '17', 'issd', '');
INSERT INTO services(port, protocol, name, description) VALUES('1601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1650', '6', 'nkd', '');
INSERT INTO services(port, protocol, name, description) VALUES('1650', '17', 'nkd', '');
INSERT INTO services(port, protocol, name, description) VALUES('1651', '6', 'proshareaudio', 'proshare conf audio');
INSERT INTO services(port, protocol, name, description) VALUES('1651', '17', 'proshareaudio', 'proshare conf audio');
INSERT INTO services(port, protocol, name, description) VALUES('1652', '6', 'prosharevideo', 'proshare conf video');
INSERT INTO services(port, protocol, name, description) VALUES('1652', '17', 'prosharevideo', 'proshare conf video');
INSERT INTO services(port, protocol, name, description) VALUES('1653', '6', 'prosharedata', 'proshare conf data');
INSERT INTO services(port, protocol, name, description) VALUES('1653', '17', 'prosharedata', 'proshare conf data');
INSERT INTO services(port, protocol, name, description) VALUES('1654', '6', 'prosharerequest', 'proshare conf request');
INSERT INTO services(port, protocol, name, description) VALUES('1654', '17', 'prosharerequest', 'proshare conf request');
INSERT INTO services(port, protocol, name, description) VALUES('1655', '6', 'prosharenotify', 'proshare conf notify');
INSERT INTO services(port, protocol, name, description) VALUES('1655', '17', 'prosharenotify', 'proshare conf notify');
INSERT INTO services(port, protocol, name, description) VALUES('1656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1661', '6', 'netview-aix-1', 'netview-aix-1');
INSERT INTO services(port, protocol, name, description) VALUES('1661', '17', 'netview-aix-1', 'netview-aix-1');
INSERT INTO services(port, protocol, name, description) VALUES('1662', '6', 'netview-aix-2', 'netview-aix-2');
INSERT INTO services(port, protocol, name, description) VALUES('1662', '17', 'netview-aix-2', 'netview-aix-2');
INSERT INTO services(port, protocol, name, description) VALUES('1663', '6', 'netview-aix-3', 'netview-aix-3');
INSERT INTO services(port, protocol, name, description) VALUES('1663', '17', 'netview-aix-3', 'netview-aix-3');
INSERT INTO services(port, protocol, name, description) VALUES('1664', '6', 'netview-aix-4', 'netview-aix-4');
INSERT INTO services(port, protocol, name, description) VALUES('1664', '17', 'netview-aix-4', 'netview-aix-4');
INSERT INTO services(port, protocol, name, description) VALUES('1665', '6', 'netview-aix-5', 'netview-aix-5');
INSERT INTO services(port, protocol, name, description) VALUES('1665', '17', 'netview-aix-5', 'netview-aix-5');
INSERT INTO services(port, protocol, name, description) VALUES('1666', '6', 'netview-aix-6', 'netview-aix-6');
INSERT INTO services(port, protocol, name, description) VALUES('1666', '17', 'netview-aix-6', 'netview-aix-6');
INSERT INTO services(port, protocol, name, description) VALUES('1667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('1986', '6', 'licensedaemon', 'cisco license management');
INSERT INTO services(port, protocol, name, description) VALUES('1986', '17', 'licensedaemon', 'cisco license management');
INSERT INTO services(port, protocol, name, description) VALUES('1987', '6', 'tr-rsrb-p1', 'cisco RSRB Priority 1 port');
INSERT INTO services(port, protocol, name, description) VALUES('1987', '17', 'tr-rsrb-p1', 'cisco RSRB Priority 1 port');
INSERT INTO services(port, protocol, name, description) VALUES('1988', '6', 'tr-rsrb-p2', 'cisco RSRB Priority 2 port');
INSERT INTO services(port, protocol, name, description) VALUES('1988', '17', 'tr-rsrb-p2', 'cisco RSRB Priority 2 port');
INSERT INTO services(port, protocol, name, description) VALUES('1989', '6', 'mshnet', 'MHSnet system');
INSERT INTO services(port, protocol, name, description) VALUES('1989', '17', 'mshnet', 'MHSnet system');
INSERT INTO services(port, protocol, name, description) VALUES('1990', '6', 'stun-p1', 'cisco STUN Priority 1 port');
INSERT INTO services(port, protocol, name, description) VALUES('1990', '17', 'stun-p1', 'cisco STUN Priority 1 port');
INSERT INTO services(port, protocol, name, description) VALUES('1991', '6', 'stun-p2', 'cisco STUN Priority 2 port');
INSERT INTO services(port, protocol, name, description) VALUES('1991', '17', 'stun-p2', 'cisco STUN Priority 2 port');
INSERT INTO services(port, protocol, name, description) VALUES('1992', '6', 'ipsendmsg', 'IPsendmsg');
INSERT INTO services(port, protocol, name, description) VALUES('1992', '17', 'ipsendmsg', 'IPsendmsg');
INSERT INTO services(port, protocol, name, description) VALUES('1993', '6', 'snmp-tcp-port', 'cisco SNMP TCP port');
INSERT INTO services(port, protocol, name, description) VALUES('1993', '17', 'snmp-tcp-port', 'cisco SNMP TCP port');
INSERT INTO services(port, protocol, name, description) VALUES('1994', '6', 'stun-port', 'cisco serial tunnel port');
INSERT INTO services(port, protocol, name, description) VALUES('1994', '17', 'stun-port', 'cisco serial tunnel port');
INSERT INTO services(port, protocol, name, description) VALUES('1995', '6', 'perf-port', 'cisco perf port');
INSERT INTO services(port, protocol, name, description) VALUES('1995', '17', 'perf-port', 'cisco perf port');
INSERT INTO services(port, protocol, name, description) VALUES('1996', '6', 'tr-rsrb-port', 'cisco Remote SRB port');
INSERT INTO services(port, protocol, name, description) VALUES('1996', '17', 'tr-rsrb-port', 'cisco Remote SRB port');
INSERT INTO services(port, protocol, name, description) VALUES('1997', '6', 'gdp-port', 'cisco Gateway Discovery Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('1997', '17', 'gdp-port', 'cisco Gateway Discovery Protocol');
INSERT INTO services(port, protocol, name, description) VALUES('1998', '6', 'x25-svc-port', 'cisco X.25 service (XOT)');
INSERT INTO services(port, protocol, name, description) VALUES('1998', '17', 'x25-svc-port', 'cisco X.25 service (XOT)');
INSERT INTO services(port, protocol, name, description) VALUES('1999', '6', 'tcp-id-port', 'cisco identification port');
INSERT INTO services(port, protocol, name, description) VALUES('1999', '17', 'tcp-id-port', 'cisco identification port');
INSERT INTO services(port, protocol, name, description) VALUES('2000', '6', 'callbook', '');
INSERT INTO services(port, protocol, name, description) VALUES('2000', '17', 'callbook', '');
INSERT INTO services(port, protocol, name, description) VALUES('2001', '6', 'dc', '');
INSERT INTO services(port, protocol, name, description) VALUES('2001', '17', 'wizard', 'curry');
INSERT INTO services(port, protocol, name, description) VALUES('2002', '6', 'globe', '');
INSERT INTO services(port, protocol, name, description) VALUES('2002', '17', 'globe', '');
INSERT INTO services(port, protocol, name, description) VALUES('2003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2004', '6', 'mailbox', '');
INSERT INTO services(port, protocol, name, description) VALUES('2004', '17', 'emce', 'CCWS mm conf');
INSERT INTO services(port, protocol, name, description) VALUES('2005', '6', 'berknet', '');
INSERT INTO services(port, protocol, name, description) VALUES('2005', '17', 'oracle', '');
INSERT INTO services(port, protocol, name, description) VALUES('2006', '6', 'invokator', '');
INSERT INTO services(port, protocol, name, description) VALUES('2006', '17', 'raid-cc', 'raid');
INSERT INTO services(port, protocol, name, description) VALUES('2007', '6', 'dectalk', '');
INSERT INTO services(port, protocol, name, description) VALUES('2007', '17', 'raid-am', '');
INSERT INTO services(port, protocol, name, description) VALUES('2008', '6', 'conf', '');
INSERT INTO services(port, protocol, name, description) VALUES('2008', '17', 'terminaldb', '');
INSERT INTO services(port, protocol, name, description) VALUES('2009', '6', 'news', '');
INSERT INTO services(port, protocol, name, description) VALUES('2009', '17', 'whosockami', '');
INSERT INTO services(port, protocol, name, description) VALUES('2010', '6', 'search', '');
INSERT INTO services(port, protocol, name, description) VALUES('2010', '17', 'pipe_server', '');
INSERT INTO services(port, protocol, name, description) VALUES('2011', '6', 'raid-cc', 'raid');
INSERT INTO services(port, protocol, name, description) VALUES('2011', '17', 'servserv', '');
INSERT INTO services(port, protocol, name, description) VALUES('2012', '6', 'ttyinfo', '');
INSERT INTO services(port, protocol, name, description) VALUES('2012', '17', 'raid-ac', '');
INSERT INTO services(port, protocol, name, description) VALUES('2013', '6', 'raid-am', '');
INSERT INTO services(port, protocol, name, description) VALUES('2013', '17', 'raid-cd', '');
INSERT INTO services(port, protocol, name, description) VALUES('2014', '6', 'troff', '');
INSERT INTO services(port, protocol, name, description) VALUES('2014', '17', 'raid-sf', '');
INSERT INTO services(port, protocol, name, description) VALUES('2015', '6', 'cypress', '');
INSERT INTO services(port, protocol, name, description) VALUES('2015', '17', 'raid-cs', '');
INSERT INTO services(port, protocol, name, description) VALUES('2016', '6', 'bootserver', '');
INSERT INTO services(port, protocol, name, description) VALUES('2016', '17', 'bootserver', '');
INSERT INTO services(port, protocol, name, description) VALUES('2017', '6', 'cypress-stat', '');
INSERT INTO services(port, protocol, name, description) VALUES('2017', '17', 'bootclient', '');
INSERT INTO services(port, protocol, name, description) VALUES('2018', '6', 'terminaldb', '');
INSERT INTO services(port, protocol, name, description) VALUES('2018', '17', 'rellpack', '');
INSERT INTO services(port, protocol, name, description) VALUES('2019', '6', 'whosockami', '');
INSERT INTO services(port, protocol, name, description) VALUES('2019', '17', 'about', '');
INSERT INTO services(port, protocol, name, description) VALUES('2020', '6', 'xinupageserver', '');
INSERT INTO services(port, protocol, name, description) VALUES('2020', '17', 'xinupageserver', '');
INSERT INTO services(port, protocol, name, description) VALUES('2021', '6', 'servexec', '');
INSERT INTO services(port, protocol, name, description) VALUES('2021', '17', 'xinuexpansion1', '');
INSERT INTO services(port, protocol, name, description) VALUES('2022', '6', 'down', '');
INSERT INTO services(port, protocol, name, description) VALUES('2022', '17', 'xinuexpansion2', '');
INSERT INTO services(port, protocol, name, description) VALUES('2023', '6', 'xinuexpansion3', '');
INSERT INTO services(port, protocol, name, description) VALUES('2023', '17', 'xinuexpansion3', '');
INSERT INTO services(port, protocol, name, description) VALUES('2024', '6', 'xinuexpansion4', '');
INSERT INTO services(port, protocol, name, description) VALUES('2024', '17', 'xinuexpansion4', '');
INSERT INTO services(port, protocol, name, description) VALUES('2025', '6', 'ellpack', '');
INSERT INTO services(port, protocol, name, description) VALUES('2025', '17', 'xribs', '');
INSERT INTO services(port, protocol, name, description) VALUES('2026', '6', 'scrabble', '');
INSERT INTO services(port, protocol, name, description) VALUES('2026', '17', 'scrabble', '');
INSERT INTO services(port, protocol, name, description) VALUES('2027', '6', 'shadowserver', '');
INSERT INTO services(port, protocol, name, description) VALUES('2027', '17', 'shadowserver', '');
INSERT INTO services(port, protocol, name, description) VALUES('2028', '6', 'submitserver', '');
INSERT INTO services(port, protocol, name, description) VALUES('2028', '17', 'submitserver', '');
INSERT INTO services(port, protocol, name, description) VALUES('2029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2030', '6', 'device2', '');
INSERT INTO services(port, protocol, name, description) VALUES('2030', '17', 'device2', '');
INSERT INTO services(port, protocol, name, description) VALUES('2031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2032', '6', 'blackboard', '');
INSERT INTO services(port, protocol, name, description) VALUES('2032', '17', 'blackboard', '');
INSERT INTO services(port, protocol, name, description) VALUES('2033', '6', 'glogger', '');
INSERT INTO services(port, protocol, name, description) VALUES('2033', '17', 'glogger', '');
INSERT INTO services(port, protocol, name, description) VALUES('2034', '6', 'scoremgr', '');
INSERT INTO services(port, protocol, name, description) VALUES('2034', '17', 'scoremgr', '');
INSERT INTO services(port, protocol, name, description) VALUES('2035', '6', 'imsldoc', '');
INSERT INTO services(port, protocol, name, description) VALUES('2035', '17', 'imsldoc', '');
INSERT INTO services(port, protocol, name, description) VALUES('2036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2038', '6', 'objectmanager', '');
INSERT INTO services(port, protocol, name, description) VALUES('2038', '17', 'objectmanager', '');
INSERT INTO services(port, protocol, name, description) VALUES('2039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2040', '6', 'lam', '');
INSERT INTO services(port, protocol, name, description) VALUES('2040', '17', 'lam', '');
INSERT INTO services(port, protocol, name, description) VALUES('2041', '6', 'interbase', '');
INSERT INTO services(port, protocol, name, description) VALUES('2041', '17', 'interbase', '');
INSERT INTO services(port, protocol, name, description) VALUES('2042', '6', 'isis', '');
INSERT INTO services(port, protocol, name, description) VALUES('2042', '17', 'isis', '');
INSERT INTO services(port, protocol, name, description) VALUES('2043', '6', 'isis-bcast', '');
INSERT INTO services(port, protocol, name, description) VALUES('2043', '17', 'isis-bcast', '');
INSERT INTO services(port, protocol, name, description) VALUES('2044', '6', 'rimsl', '');
INSERT INTO services(port, protocol, name, description) VALUES('2044', '17', 'rimsl', '');
INSERT INTO services(port, protocol, name, description) VALUES('2045', '6', 'cdfunc', '');
INSERT INTO services(port, protocol, name, description) VALUES('2045', '17', 'cdfunc', '');
INSERT INTO services(port, protocol, name, description) VALUES('2046', '6', 'sdfunc', '');
INSERT INTO services(port, protocol, name, description) VALUES('2046', '17', 'sdfunc', '');
INSERT INTO services(port, protocol, name, description) VALUES('2047', '6', 'dls', '');
INSERT INTO services(port, protocol, name, description) VALUES('2047', '17', 'dls', '');
INSERT INTO services(port, protocol, name, description) VALUES('2048', '6', 'dls-monitor', '');
INSERT INTO services(port, protocol, name, description) VALUES('2048', '17', 'dls-monitor', '');
INSERT INTO services(port, protocol, name, description) VALUES('2049', '6', 'shilp', '');
INSERT INTO services(port, protocol, name, description) VALUES('2049', '17', 'shilp', '');
INSERT INTO services(port, protocol, name, description) VALUES('2050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2065', '6', 'dlsrpn', 'Data Link Switch Read Port Number');
INSERT INTO services(port, protocol, name, description) VALUES('2065', '17', 'dlsrpn', 'Data Link Switch Read Port Number');
INSERT INTO services(port, protocol, name, description) VALUES('2066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2067', '6', 'dlswpn', 'Data Link Switch Write Port Number');
INSERT INTO services(port, protocol, name, description) VALUES('2067', '17', 'dlswpn', 'Data Link Switch Write Port Number');
INSERT INTO services(port, protocol, name, description) VALUES('2068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2201', '6', 'ats', 'Advanced Training System Program');
INSERT INTO services(port, protocol, name, description) VALUES('2201', '17', 'ats', 'Advanced Training System Program');
INSERT INTO services(port, protocol, name, description) VALUES('2202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2500', '6', 'rtsserv', 'Resource Tracking system server');
INSERT INTO services(port, protocol, name, description) VALUES('2500', '17', 'rtsserv', 'Resource Tracking system server');
INSERT INTO services(port, protocol, name, description) VALUES('2501', '6', 'rtsclient', 'Resource Tracking system client');
INSERT INTO services(port, protocol, name, description) VALUES('2501', '17', 'rtsclient', 'Resource Tracking system client');
INSERT INTO services(port, protocol, name, description) VALUES('2502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2564', '6', 'hp-3000-telnet', 'HP 3000 NS/VT block mode telnet');
INSERT INTO services(port, protocol, name, description) VALUES('2564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2784', '6', 'www-dev', 'world wide web - development');
INSERT INTO services(port, protocol, name, description) VALUES('2784', '17', 'www-dev', 'world wide web - development');
INSERT INTO services(port, protocol, name, description) VALUES('2785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('2999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3049', '6', 'NSWS', '');
INSERT INTO services(port, protocol, name, description) VALUES('3049', '17', 'NSWS', '');
INSERT INTO services(port, protocol, name, description) VALUES('3050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3264', '6', 'ccmail', 'cc:mail/lotus');
INSERT INTO services(port, protocol, name, description) VALUES('3264', '17', 'ccmail', 'cc:mail/lotus');
INSERT INTO services(port, protocol, name, description) VALUES('3265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3333', '6', 'dec-notes', 'DEC Notes');
INSERT INTO services(port, protocol, name, description) VALUES('3333', '17', 'dec-notes', 'DEC Notes');
INSERT INTO services(port, protocol, name, description) VALUES('3334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3421', '6', 'bmap', 'Bull Apprise portmapper');
INSERT INTO services(port, protocol, name, description) VALUES('3421', '17', 'bmap', 'Bull Apprise portmapper');
INSERT INTO services(port, protocol, name, description) VALUES('3422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3900', '6', 'udt_os', 'Unidata UDT OS');
INSERT INTO services(port, protocol, name, description) VALUES('3900', '17', 'udt_os', 'Unidata UDT OS');
INSERT INTO services(port, protocol, name, description) VALUES('3901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3984', '6', 'mapper-nodemgr', 'MAPPER network node manager');
INSERT INTO services(port, protocol, name, description) VALUES('3984', '17', 'mapper-nodemgr', 'MAPPER network node manager');
INSERT INTO services(port, protocol, name, description) VALUES('3985', '6', 'mapper-mapethd', 'MAPPER TCP/IP server');
INSERT INTO services(port, protocol, name, description) VALUES('3985', '17', 'mapper-mapethd', 'MAPPER TCP/IP server');
INSERT INTO services(port, protocol, name, description) VALUES('3986', '6', 'mapper-ws_ethd', 'MAPPER workstation server');
INSERT INTO services(port, protocol, name, description) VALUES('3986', '17', 'mapper-ws_ethd', 'MAPPER workstation server');
INSERT INTO services(port, protocol, name, description) VALUES('3987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('3999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4132', '6', 'nuts_dem', 'NUTS Daemon');
INSERT INTO services(port, protocol, name, description) VALUES('4132', '17', 'nuts_dem', 'NUTS Daemon');
INSERT INTO services(port, protocol, name, description) VALUES('4133', '6', 'nuts_bootp', 'NUTS Bootp Server');
INSERT INTO services(port, protocol, name, description) VALUES('4133', '17', 'nuts_bootp', 'NUTS Bootp Server');
INSERT INTO services(port, protocol, name, description) VALUES('4134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4343', '6', 'unicall', 'UNICALL');
INSERT INTO services(port, protocol, name, description) VALUES('4343', '17', 'unicall', 'UNICALL');
INSERT INTO services(port, protocol, name, description) VALUES('4344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4444', '6', 'krb524', 'KRB524');
INSERT INTO services(port, protocol, name, description) VALUES('4444', '17', 'krb524', 'KRB524');
INSERT INTO services(port, protocol, name, description) VALUES('4445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4672', '6', 'rfa', 'remote file access server');
INSERT INTO services(port, protocol, name, description) VALUES('4672', '17', 'rfa', 'remote file access server');
INSERT INTO services(port, protocol, name, description) VALUES('4673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('4999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5000', '6', 'commplex-main', '');
INSERT INTO services(port, protocol, name, description) VALUES('5000', '17', 'commplex-main', '');
INSERT INTO services(port, protocol, name, description) VALUES('5001', '6', 'commplex-link', '');
INSERT INTO services(port, protocol, name, description) VALUES('5001', '17', 'commplex-link', '');
INSERT INTO services(port, protocol, name, description) VALUES('5002', '6', 'rfe', 'radio free ethernet');
INSERT INTO services(port, protocol, name, description) VALUES('5002', '17', 'rfe', 'radio free ethernet');
INSERT INTO services(port, protocol, name, description) VALUES('5003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5010', '6', 'telelpathstart', 'TelepathStart');
INSERT INTO services(port, protocol, name, description) VALUES('5010', '17', 'telelpathstart', 'TelepathStart');
INSERT INTO services(port, protocol, name, description) VALUES('5011', '6', 'telelpathattack', 'TelepathAttack');
INSERT INTO services(port, protocol, name, description) VALUES('5011', '17', 'telelpathattack', 'TelepathAttack');
INSERT INTO services(port, protocol, name, description) VALUES('5012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5050', '6', 'mmcc', 'multimedia conference control tool');
INSERT INTO services(port, protocol, name, description) VALUES('5050', '17', 'mmcc', 'multimedia conference control tool');
INSERT INTO services(port, protocol, name, description) VALUES('5051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5145', '6', 'rmonitor_secure', '');
INSERT INTO services(port, protocol, name, description) VALUES('5145', '17', 'rmonitor_secure', '');
INSERT INTO services(port, protocol, name, description) VALUES('5146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5190', '6', 'aol', 'America-Online');
INSERT INTO services(port, protocol, name, description) VALUES('5190', '17', 'aol', 'America-Online');
INSERT INTO services(port, protocol, name, description) VALUES('5191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5236', '6', 'padl2sim', '');
INSERT INTO services(port, protocol, name, description) VALUES('5236', '17', 'padl2sim', '');
INSERT INTO services(port, protocol, name, description) VALUES('5237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5300', '6', 'hacl-hb', '# HA cluster heartbeat');
INSERT INTO services(port, protocol, name, description) VALUES('5300', '17', 'hacl-hb', '# HA cluster heartbeat');
INSERT INTO services(port, protocol, name, description) VALUES('5301', '6', 'hacl-gs', '# HA cluster general services');
INSERT INTO services(port, protocol, name, description) VALUES('5301', '17', 'hacl-gs', '# HA cluster general services');
INSERT INTO services(port, protocol, name, description) VALUES('5302', '6', 'hacl-cfg', '# HA cluster configuration');
INSERT INTO services(port, protocol, name, description) VALUES('5302', '17', 'hacl-cfg', '# HA cluster configuration');
INSERT INTO services(port, protocol, name, description) VALUES('5303', '6', 'hacl-probe', '# HA cluster probing');
INSERT INTO services(port, protocol, name, description) VALUES('5303', '17', 'hacl-probe', '# HA cluster probing');
INSERT INTO services(port, protocol, name, description) VALUES('5304', '6', 'hacl-local', '');
INSERT INTO services(port, protocol, name, description) VALUES('5304', '17', 'hacl-local', '');
INSERT INTO services(port, protocol, name, description) VALUES('5305', '6', 'hacl-test', '');
INSERT INTO services(port, protocol, name, description) VALUES('5305', '17', 'hacl-test', '');
INSERT INTO services(port, protocol, name, description) VALUES('5306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('5999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6111', '6', 'sub-process', 'HP SoftBench Sub-Process Control');
INSERT INTO services(port, protocol, name, description) VALUES('6111', '17', 'sub-process', 'HP SoftBench Sub-Process Control');
INSERT INTO services(port, protocol, name, description) VALUES('6112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6141', '6', 'meta-corp', 'Meta Corporation License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('6141', '17', 'meta-corp', 'Meta Corporation License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('6142', '6', 'aspentec-lm', 'Aspen Technology License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('6142', '17', 'aspentec-lm', 'Aspen Technology License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('6143', '6', 'watershed-lm', 'Watershed License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('6143', '17', 'watershed-lm', 'Watershed License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('6144', '6', 'statsci1-lm', 'StatSci License Manager - 1');
INSERT INTO services(port, protocol, name, description) VALUES('6144', '17', 'statsci1-lm', 'StatSci License Manager - 1');
INSERT INTO services(port, protocol, name, description) VALUES('6145', '6', 'statsci2-lm', 'StatSci License Manager - 2');
INSERT INTO services(port, protocol, name, description) VALUES('6145', '17', 'statsci2-lm', 'StatSci License Manager - 2');
INSERT INTO services(port, protocol, name, description) VALUES('6146', '6', 'lonewolf-lm', 'Lone Wolf Systems License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('6146', '17', 'lonewolf-lm', 'Lone Wolf Systems License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('6147', '6', 'montage-lm', 'Montage License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('6147', '17', 'montage-lm', 'Montage License Manager');
INSERT INTO services(port, protocol, name, description) VALUES('6148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6558', '6', 'xdsxdm', '');
INSERT INTO services(port, protocol, name, description) VALUES('6558', '17', 'xdsxdm', '');
INSERT INTO services(port, protocol, name, description) VALUES('6559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('6999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7000', '6', 'afs3-fileserver', 'file server itself');
INSERT INTO services(port, protocol, name, description) VALUES('7000', '17', 'afs3-fileserver', 'file server itself');
INSERT INTO services(port, protocol, name, description) VALUES('7001', '6', 'afs3-callback', 'callbacks to cache managers');
INSERT INTO services(port, protocol, name, description) VALUES('7001', '17', 'afs3-callback', 'callbacks to cache managers');
INSERT INTO services(port, protocol, name, description) VALUES('7002', '6', 'afs3-prserver', 'users & groups database');
INSERT INTO services(port, protocol, name, description) VALUES('7002', '17', 'afs3-prserver', 'users & groups database');
INSERT INTO services(port, protocol, name, description) VALUES('7003', '6', 'afs3-vlserver', 'volume location database');
INSERT INTO services(port, protocol, name, description) VALUES('7003', '17', 'afs3-vlserver', 'volume location database');
INSERT INTO services(port, protocol, name, description) VALUES('7004', '6', 'afs3-kaserver', 'AFS/Kerberos authentication service');
INSERT INTO services(port, protocol, name, description) VALUES('7004', '17', 'afs3-kaserver', 'AFS/Kerberos authentication service');
INSERT INTO services(port, protocol, name, description) VALUES('7005', '6', 'afs3-volser', 'volume managment server');
INSERT INTO services(port, protocol, name, description) VALUES('7005', '17', 'afs3-volser', 'volume managment server');
INSERT INTO services(port, protocol, name, description) VALUES('7006', '6', 'afs3-errors', 'error interpretation service');
INSERT INTO services(port, protocol, name, description) VALUES('7006', '17', 'afs3-errors', 'error interpretation service');
INSERT INTO services(port, protocol, name, description) VALUES('7007', '6', 'afs3-bos', 'basic overseer process');
INSERT INTO services(port, protocol, name, description) VALUES('7007', '17', 'afs3-bos', 'basic overseer process');
INSERT INTO services(port, protocol, name, description) VALUES('7008', '6', 'afs3-update', 'server-to-server updater');
INSERT INTO services(port, protocol, name, description) VALUES('7008', '17', 'afs3-update', 'server-to-server updater');
INSERT INTO services(port, protocol, name, description) VALUES('7009', '6', 'afs3-rmtsys', 'remote cache manager service');
INSERT INTO services(port, protocol, name, description) VALUES('7009', '17', 'afs3-rmtsys', 'remote cache manager service');
INSERT INTO services(port, protocol, name, description) VALUES('7010', '6', 'ups-onlinet', 'onlinet uninterruptable power supplies');
INSERT INTO services(port, protocol, name, description) VALUES('7010', '17', 'ups-onlinet', 'onlinet uninterruptable power supplies');
INSERT INTO services(port, protocol, name, description) VALUES('7011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7100', '6', 'font-service', 'X Font Service');
INSERT INTO services(port, protocol, name, description) VALUES('7100', '17', 'font-service', 'X Font Service');
INSERT INTO services(port, protocol, name, description) VALUES('7101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7200', '6', 'fodms', 'FODMS FLIP');
INSERT INTO services(port, protocol, name, description) VALUES('7200', '17', 'fodms', 'FODMS FLIP');
INSERT INTO services(port, protocol, name, description) VALUES('7201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('7999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('8999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9535', '6', 'man', '');
INSERT INTO services(port, protocol, name, description) VALUES('9535', '17', 'man', '');
INSERT INTO services(port, protocol, name, description) VALUES('9536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('9999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('10999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('11999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('12999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('13999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('14999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('15999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('16999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17007', '6', 'isode-dua', '');
INSERT INTO services(port, protocol, name, description) VALUES('17007', '17', 'isode-dua', '');
INSERT INTO services(port, protocol, name, description) VALUES('17008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('17999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('18999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('19999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('20999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('21999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('22999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('23999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('24999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('25999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('26999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('27999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('28999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('29999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('30999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('31999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('32999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('33999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('34999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('35999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('36999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('37999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('38999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('39999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('40999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('41999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('42999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('43999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('44999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('45999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('46999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('47999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('48999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('49999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('50999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('51999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('52999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('53999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('54999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('55999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('56999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('57999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('58999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('59999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('60999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('61999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('62999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('63999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64535', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64536', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64536', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64537', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64537', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64538', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64538', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64539', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64539', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64540', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64540', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64541', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64541', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64542', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64542', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64543', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64543', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64544', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64544', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64545', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64545', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64546', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64546', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64547', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64547', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64548', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64548', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64549', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64549', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64550', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64550', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64551', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64551', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64552', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64552', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64553', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64553', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64554', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64554', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64555', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64555', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64556', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64556', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64557', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64557', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64558', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64558', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64559', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64559', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64560', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64560', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64561', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64561', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64562', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64562', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64563', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64563', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64564', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64564', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64565', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64565', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64566', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64566', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64567', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64567', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64568', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64568', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64569', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64569', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64570', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64570', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64571', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64571', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64572', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64572', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64573', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64573', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64574', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64574', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64575', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64575', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64576', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64576', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64577', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64577', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64578', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64578', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64579', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64579', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64580', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64580', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64581', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64581', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64582', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64582', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64583', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64583', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64584', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64584', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64585', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64585', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64586', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64586', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64587', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64587', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64588', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64588', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64589', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64589', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64590', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64590', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64591', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64591', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64592', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64592', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64593', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64593', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64594', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64594', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64595', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64595', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64596', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64596', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64597', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64597', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64598', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64598', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64599', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64599', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64600', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64600', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64601', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64601', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64602', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64602', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64603', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64603', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64604', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64604', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64605', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64605', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64606', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64606', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64607', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64607', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64608', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64608', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64609', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64609', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64610', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64610', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64611', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64611', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64612', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64612', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64613', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64613', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64614', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64614', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64615', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64615', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64616', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64616', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64617', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64617', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64618', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64618', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64619', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64619', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64620', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64620', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64621', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64621', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64622', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64622', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64623', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64623', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64624', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64624', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64625', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64625', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64626', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64626', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64627', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64627', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64628', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64628', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64629', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64629', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64630', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64630', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64631', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64631', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64632', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64632', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64633', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64633', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64634', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64634', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64635', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64635', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64636', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64636', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64637', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64637', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64638', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64638', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64639', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64639', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64640', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64640', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64641', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64641', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64642', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64642', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64643', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64643', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64644', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64644', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64645', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64645', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64646', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64646', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64647', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64647', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64648', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64648', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64649', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64649', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64650', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64650', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64651', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64651', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64652', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64652', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64653', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64653', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64654', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64654', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64655', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64655', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64656', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64656', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64657', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64657', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64658', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64658', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64659', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64659', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64660', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64660', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64661', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64661', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64662', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64662', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64663', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64663', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64664', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64664', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64665', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64665', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64666', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64666', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64667', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64667', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64668', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64668', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64669', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64669', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64670', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64670', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64671', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64671', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64672', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64672', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64673', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64673', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64674', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64674', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64675', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64675', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64676', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64676', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64677', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64677', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64678', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64678', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64679', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64679', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64680', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64680', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64681', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64681', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64682', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64682', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64683', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64683', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64684', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64684', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64685', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64685', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64686', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64686', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64687', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64687', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64688', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64688', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64689', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64689', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64690', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64690', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64691', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64691', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64692', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64692', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64693', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64693', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64694', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64694', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64695', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64695', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64696', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64696', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64697', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64697', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64698', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64698', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64699', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64699', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64700', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64700', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64701', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64701', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64702', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64702', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64703', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64703', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64704', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64704', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64705', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64705', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64706', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64706', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64707', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64707', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64708', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64708', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64709', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64709', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64710', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64710', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64711', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64711', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64712', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64712', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64713', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64713', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64714', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64714', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64715', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64715', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64716', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64716', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64717', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64717', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64718', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64718', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64719', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64719', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64720', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64720', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64721', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64721', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64722', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64722', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64723', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64723', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64724', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64724', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64725', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64725', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64726', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64726', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64727', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64727', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64728', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64728', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64729', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64729', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64730', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64730', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64731', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64731', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64732', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64732', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64733', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64733', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64734', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64734', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64735', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64735', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64736', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64736', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64737', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64737', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64738', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64738', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64739', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64739', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64740', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64740', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64741', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64741', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64742', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64742', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64743', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64743', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64744', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64744', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64745', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64745', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64746', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64746', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64747', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64747', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64748', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64748', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64749', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64749', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64750', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64750', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64751', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64751', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64752', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64752', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64753', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64753', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64754', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64754', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64755', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64755', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64756', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64756', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64757', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64757', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64758', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64758', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64759', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64759', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64760', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64760', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64761', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64761', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64762', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64762', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64763', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64763', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64764', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64764', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64765', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64765', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64766', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64766', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64767', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64767', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64768', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64768', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64769', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64769', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64770', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64770', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64771', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64771', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64772', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64772', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64773', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64773', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64774', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64774', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64775', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64775', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64776', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64776', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64777', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64777', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64778', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64778', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64779', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64779', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64780', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64780', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64781', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64781', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64782', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64782', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64783', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64783', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64784', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64784', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64785', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64785', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64786', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64786', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64787', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64787', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64788', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64788', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64789', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64789', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64790', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64790', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64791', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64791', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64792', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64792', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64793', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64793', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64794', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64794', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64795', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64795', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64796', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64796', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64797', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64797', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64798', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64798', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64799', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64799', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64800', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64800', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64801', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64801', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64802', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64802', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64803', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64803', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64804', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64804', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64805', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64805', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64806', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64806', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64807', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64807', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64808', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64808', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64809', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64809', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64810', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64810', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64811', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64811', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64812', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64812', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64813', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64813', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64814', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64814', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64815', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64815', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64816', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64816', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64817', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64817', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64818', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64818', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64819', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64819', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64820', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64820', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64821', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64821', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64822', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64822', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64823', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64823', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64824', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64824', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64825', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64825', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64826', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64826', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64827', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64827', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64828', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64828', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64829', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64829', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64830', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64830', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64831', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64831', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64832', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64832', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64833', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64833', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64834', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64834', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64835', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64835', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64836', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64836', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64837', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64837', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64838', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64838', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64839', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64839', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64840', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64840', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64841', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64841', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64842', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64842', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64843', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64843', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64844', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64844', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64845', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64845', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64846', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64846', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64847', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64847', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64848', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64848', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64849', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64849', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64850', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64850', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64851', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64851', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64852', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64852', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64853', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64853', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64854', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64854', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64855', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64855', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64856', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64856', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64857', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64857', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64858', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64858', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64859', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64859', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64860', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64860', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64861', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64861', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64862', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64862', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64863', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64863', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64864', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64864', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64865', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64865', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64866', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64866', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64867', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64867', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64868', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64868', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64869', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64869', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64870', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64870', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64871', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64871', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64872', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64872', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64873', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64873', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64874', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64874', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64875', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64875', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64876', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64876', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64877', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64877', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64878', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64878', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64879', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64879', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64880', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64880', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64881', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64881', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64882', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64882', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64883', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64883', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64884', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64884', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64885', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64885', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64886', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64886', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64887', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64887', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64888', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64888', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64889', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64889', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64890', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64890', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64891', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64891', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64892', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64892', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64893', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64893', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64894', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64894', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64895', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64895', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64896', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64896', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64897', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64897', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64898', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64898', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64899', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64899', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64900', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64900', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64901', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64901', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64902', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64902', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64903', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64903', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64904', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64904', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64905', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64905', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64906', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64906', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64907', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64907', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64908', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64908', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64909', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64909', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64910', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64910', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64911', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64911', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64912', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64912', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64913', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64913', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64914', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64914', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64915', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64915', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64916', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64916', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64917', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64917', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64918', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64918', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64919', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64919', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64920', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64920', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64921', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64921', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64922', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64922', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64923', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64923', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64924', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64924', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64925', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64925', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64926', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64926', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64927', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64927', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64928', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64928', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64929', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64929', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64930', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64930', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64931', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64931', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64932', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64932', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64933', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64933', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64934', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64934', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64935', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64935', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64936', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64936', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64937', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64937', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64938', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64938', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64939', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64939', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64940', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64940', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64941', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64941', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64942', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64942', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64943', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64943', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64944', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64944', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64945', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64945', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64946', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64946', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64947', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64947', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64948', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64948', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64949', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64949', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64950', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64950', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64951', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64951', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64952', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64952', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64953', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64953', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64954', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64954', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64955', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64955', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64956', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64956', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64957', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64957', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64958', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64958', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64959', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64959', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64960', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64960', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64961', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64961', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64962', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64962', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64963', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64963', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64964', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64964', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64965', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64965', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64966', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64966', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64967', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64967', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64968', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64968', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64969', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64969', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64970', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64970', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64971', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64971', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64972', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64972', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64973', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64973', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64974', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64974', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64975', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64975', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64976', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64976', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64977', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64977', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64978', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64978', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64979', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64979', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64980', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64980', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64981', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64981', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64982', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64982', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64983', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64983', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64984', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64984', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64985', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64985', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64986', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64986', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64987', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64987', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64988', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64988', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64989', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64989', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64990', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64990', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64991', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64991', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64992', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64992', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64993', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64993', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64994', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64994', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64995', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64995', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64996', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64996', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64997', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64997', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64998', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64998', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64999', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('64999', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65000', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65000', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65001', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65001', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65002', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65002', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65003', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65003', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65004', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65004', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65005', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65005', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65006', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65006', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65007', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65007', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65008', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65008', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65009', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65009', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65010', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65010', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65011', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65011', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65012', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65012', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65013', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65013', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65014', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65014', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65015', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65015', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65016', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65016', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65017', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65017', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65018', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65018', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65019', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65019', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65020', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65020', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65021', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65021', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65022', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65022', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65023', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65023', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65024', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65024', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65025', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65025', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65026', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65026', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65027', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65027', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65028', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65028', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65029', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65029', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65030', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65030', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65031', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65031', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65032', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65032', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65033', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65033', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65034', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65034', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65035', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65035', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65036', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65036', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65037', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65037', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65038', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65038', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65039', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65039', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65040', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65040', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65041', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65041', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65042', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65042', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65043', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65043', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65044', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65044', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65045', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65045', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65046', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65046', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65047', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65047', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65048', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65048', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65049', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65049', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65050', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65050', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65051', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65051', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65052', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65052', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65053', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65053', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65054', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65054', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65055', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65055', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65056', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65056', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65057', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65057', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65058', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65058', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65059', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65059', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65060', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65060', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65061', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65061', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65062', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65062', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65063', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65063', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65064', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65064', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65065', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65065', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65066', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65066', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65067', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65067', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65068', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65068', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65069', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65069', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65070', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65070', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65071', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65071', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65072', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65072', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65073', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65073', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65074', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65074', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65075', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65075', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65076', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65076', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65077', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65077', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65078', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65078', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65079', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65079', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65080', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65080', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65081', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65081', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65082', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65082', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65083', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65083', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65084', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65084', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65085', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65085', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65086', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65086', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65087', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65087', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65088', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65088', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65089', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65089', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65090', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65090', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65091', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65091', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65092', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65092', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65093', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65093', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65094', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65094', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65095', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65095', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65096', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65096', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65097', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65097', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65098', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65098', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65099', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65099', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65100', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65100', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65101', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65101', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65102', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65102', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65103', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65103', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65104', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65104', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65105', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65105', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65106', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65106', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65107', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65107', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65108', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65108', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65109', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65109', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65110', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65110', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65111', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65111', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65112', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65112', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65113', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65113', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65114', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65114', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65115', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65115', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65116', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65116', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65117', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65117', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65118', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65118', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65119', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65119', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65120', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65120', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65121', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65121', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65122', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65122', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65123', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65123', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65124', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65124', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65125', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65125', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65126', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65126', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65127', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65127', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65128', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65128', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65129', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65129', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65130', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65130', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65131', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65131', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65132', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65132', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65133', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65133', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65134', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65134', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65135', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65135', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65136', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65136', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65137', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65137', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65138', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65138', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65139', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65139', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65140', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65140', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65141', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65141', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65142', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65142', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65143', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65143', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65144', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65144', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65145', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65145', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65146', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65146', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65147', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65147', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65148', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65148', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65149', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65149', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65150', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65150', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65151', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65151', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65152', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65152', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65153', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65153', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65154', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65154', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65155', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65155', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65156', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65156', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65157', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65157', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65158', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65158', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65159', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65159', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65160', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65160', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65161', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65161', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65162', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65162', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65163', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65163', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65164', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65164', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65165', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65165', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65166', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65166', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65167', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65167', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65168', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65168', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65169', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65169', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65170', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65170', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65171', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65171', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65172', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65172', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65173', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65173', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65174', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65174', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65175', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65175', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65176', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65176', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65177', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65177', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65178', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65178', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65179', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65179', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65180', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65180', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65181', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65181', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65182', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65182', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65183', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65183', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65184', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65184', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65185', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65185', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65186', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65186', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65187', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65187', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65188', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65188', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65189', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65189', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65190', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65190', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65191', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65191', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65192', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65192', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65193', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65193', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65194', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65194', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65195', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65195', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65196', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65196', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65197', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65197', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65198', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65198', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65199', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65199', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65200', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65200', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65201', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65201', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65202', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65202', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65203', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65203', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65204', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65204', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65205', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65205', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65206', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65206', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65207', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65207', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65208', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65208', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65209', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65209', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65210', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65210', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65211', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65211', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65212', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65212', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65213', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65213', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65214', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65214', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65215', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65215', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65216', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65216', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65217', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65217', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65218', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65218', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65219', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65219', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65220', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65220', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65221', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65221', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65222', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65222', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65223', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65223', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65224', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65224', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65225', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65225', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65226', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65226', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65227', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65227', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65228', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65228', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65229', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65229', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65230', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65230', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65231', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65231', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65232', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65232', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65233', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65233', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65234', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65234', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65235', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65235', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65236', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65236', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65237', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65237', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65238', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65238', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65239', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65239', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65240', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65240', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65241', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65241', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65242', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65242', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65243', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65243', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65244', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65244', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65245', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65245', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65246', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65246', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65247', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65247', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65248', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65248', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65249', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65249', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65250', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65250', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65251', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65251', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65252', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65252', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65253', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65253', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65254', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65254', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65255', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65255', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65256', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65256', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65257', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65257', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65258', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65258', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65259', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65259', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65260', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65260', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65261', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65261', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65262', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65262', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65263', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65263', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65264', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65264', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65265', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65265', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65266', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65266', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65267', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65267', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65268', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65268', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65269', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65269', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65270', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65270', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65271', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65271', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65272', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65272', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65273', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65273', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65274', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65274', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65275', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65275', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65276', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65276', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65277', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65277', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65278', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65278', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65279', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65279', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65280', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65280', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65281', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65281', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65282', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65282', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65283', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65283', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65284', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65284', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65285', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65285', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65286', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65286', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65287', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65287', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65288', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65288', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65289', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65289', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65290', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65290', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65291', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65291', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65292', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65292', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65293', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65293', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65294', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65294', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65295', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65295', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65296', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65296', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65297', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65297', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65298', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65298', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65299', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65299', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65300', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65300', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65301', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65301', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65302', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65302', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65303', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65303', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65304', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65304', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65305', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65305', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65306', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65306', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65307', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65307', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65308', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65308', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65309', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65309', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65310', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65310', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65311', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65311', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65312', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65312', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65313', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65313', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65314', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65314', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65315', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65315', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65316', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65316', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65317', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65317', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65318', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65318', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65319', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65319', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65320', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65320', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65321', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65321', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65322', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65322', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65323', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65323', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65324', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65324', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65325', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65325', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65326', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65326', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65327', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65327', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65328', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65328', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65329', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65329', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65330', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65330', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65331', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65331', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65332', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65332', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65333', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65333', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65334', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65334', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65335', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65335', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65336', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65336', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65337', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65337', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65338', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65338', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65339', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65339', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65340', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65340', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65341', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65341', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65342', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65342', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65343', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65343', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65344', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65344', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65345', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65345', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65346', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65346', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65347', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65347', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65348', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65348', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65349', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65349', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65350', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65350', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65351', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65351', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65352', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65352', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65353', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65353', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65354', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65354', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65355', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65355', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65356', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65356', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65357', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65357', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65358', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65358', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65359', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65359', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65360', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65360', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65361', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65361', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65362', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65362', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65363', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65363', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65364', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65364', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65365', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65365', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65366', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65366', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65367', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65367', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65368', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65368', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65369', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65369', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65370', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65370', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65371', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65371', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65372', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65372', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65373', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65373', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65374', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65374', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65375', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65375', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65376', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65376', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65377', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65377', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65378', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65378', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65379', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65379', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65380', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65380', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65381', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65381', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65382', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65382', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65383', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65383', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65384', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65384', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65385', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65385', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65386', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65386', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65387', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65387', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65388', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65388', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65389', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65389', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65390', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65390', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65391', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65391', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65392', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65392', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65393', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65393', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65394', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65394', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65395', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65395', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65396', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65396', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65397', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65397', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65398', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65398', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65399', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65399', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65400', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65400', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65401', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65401', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65402', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65402', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65403', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65403', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65404', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65404', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65405', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65405', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65406', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65406', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65407', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65407', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65408', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65408', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65409', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65409', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65410', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65410', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65411', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65411', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65412', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65412', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65413', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65413', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65414', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65414', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65415', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65415', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65416', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65416', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65417', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65417', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65418', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65418', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65419', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65419', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65420', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65420', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65421', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65421', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65422', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65422', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65423', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65423', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65424', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65424', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65425', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65425', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65426', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65426', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65427', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65427', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65428', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65428', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65429', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65429', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65430', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65430', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65431', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65431', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65432', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65432', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65433', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65433', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65434', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65434', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65435', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65435', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65436', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65436', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65437', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65437', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65438', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65438', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65439', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65439', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65440', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65440', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65441', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65441', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65442', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65442', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65443', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65443', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65444', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65444', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65445', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65445', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65446', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65446', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65447', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65447', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65448', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65448', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65449', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65449', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65450', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65450', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65451', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65451', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65452', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65452', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65453', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65453', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65454', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65454', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65455', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65455', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65456', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65456', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65457', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65457', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65458', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65458', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65459', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65459', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65460', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65460', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65461', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65461', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65462', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65462', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65463', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65463', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65464', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65464', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65465', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65465', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65466', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65466', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65467', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65467', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65468', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65468', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65469', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65469', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65470', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65470', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65471', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65471', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65472', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65472', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65473', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65473', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65474', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65474', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65475', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65475', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65476', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65476', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65477', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65477', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65478', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65478', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65479', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65479', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65480', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65480', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65481', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65481', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65482', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65482', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65483', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65483', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65484', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65484', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65485', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65485', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65486', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65486', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65487', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65487', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65488', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65488', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65489', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65489', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65490', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65490', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65491', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65491', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65492', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65492', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65493', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65493', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65494', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65494', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65495', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65495', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65496', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65496', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65497', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65497', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65498', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65498', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65499', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65499', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65500', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65500', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65501', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65501', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65502', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65502', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65503', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65503', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65504', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65504', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65505', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65505', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65506', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65506', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65507', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65507', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65508', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65508', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65509', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65509', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65510', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65510', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65511', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65511', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65512', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65512', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65513', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65513', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65514', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65514', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65515', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65515', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65516', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65516', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65517', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65517', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65518', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65518', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65519', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65519', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65520', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65520', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65521', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65521', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65522', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65522', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65523', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65523', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65524', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65524', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65525', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65525', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65526', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65526', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65527', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65527', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65528', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65528', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65529', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65529', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65530', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65530', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65531', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65531', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65532', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65532', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65533', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65533', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65534', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65534', '17', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65535', '6', '-', 'Unassigned');
INSERT INTO services(port, protocol, name, description) VALUES('65535', '17', '-', 'Unassigned');

INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 'NULL Packet');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 'NULL Packet (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(2, 0, 1, 0, 0, 0, 0, 0, 0, 0, 'NULL Packet (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 'NULL Packet (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(4, 0, 0, 1, 0, 0, 0, 0, 0, 0, 'URG: Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(5, 1, 0, 1, 0, 0, 0, 0, 0, 0, 'URG: Standard/Invalid (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(6, 0, 1, 1, 0, 0, 0, 0, 0, 0, 'URG: Standard/Invalid (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(7, 1, 1, 1, 0, 0, 0, 0, 0, 0, 'URG: Standard/Invalid (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(8, 0, 0, 0, 1, 0, 0, 0, 0, 1, 'ACK: Acknowlege packet');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(9, 1, 0, 0, 1, 0, 0, 0, 0, 1, 'ACK: Acknowlege packeStandard/Invalid (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(10, 0, 1, 0, 1, 0, 0, 0, 0, 1, 'ACK: Acknowlege packeStandard/Invalid (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(11, 1, 1, 0, 1, 0, 0, 0, 0, 1, 'ACK: Acknowlege packeStandard/Invalid (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(12, 0, 0, 1, 1, 0, 0, 0, 0, 1, 'URG|ACK: Urgent field active with acknowlegement of packet');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(13, 1, 0, 1, 1, 0, 0, 0, 0, 1, 'URG|ACK: Urgent field active with acknowlegement of packet (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(14, 0, 1, 1, 1, 0, 0, 0, 0, 1, 'URG|ACK: Urgent field active with acknowlegement of packet (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(15, 1, 1, 1, 1, 0, 0, 0, 0, 1, 'URG|ACK: Urgent field active with acknowlegement of packet (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(16, 0, 0, 0, 0, 1, 0, 0, 0, 0, 'PSH: Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(17, 1, 0, 0, 0, 1, 0, 0, 0, 0, 'PSH: Standard/Invalid (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(18, 0, 1, 0, 0, 1, 0, 0, 0, 0, 'PSH: Standard/Invalid (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(19, 1, 1, 0, 0, 1, 0, 0, 0, 0, 'PSH: Standard/Invalid (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(20, 0, 0, 1, 0, 1, 0, 0, 0, 1, 'URG|PSH: Urgent field active and push data');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(21, 1, 0, 1, 0, 1, 0, 0, 0, 1, 'URG|PSH: Urgent field active and push data (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(22, 0, 1, 1, 0, 1, 0, 0, 0, 1, 'URG|PSH: Urgent field active and push data (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(23, 1, 1, 1, 0, 1, 0, 0, 0, 1, 'URG|PSH: Urgent field active and push data (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(24, 0, 0, 0, 1, 1, 0, 0, 0, 1, 'ACK|PSH: Acknowlegement with a push on packet');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(25, 1, 0, 0, 1, 1, 0, 0, 0, 1, 'ACK|PSH: Acknowlegement with a push on packet (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(26, 0, 1, 0, 1, 1, 0, 0, 0, 1, 'ACK|PSH: Acknowlegement with a push on packet (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(27, 1, 1, 0, 1, 1, 0, 0, 0, 1, 'ACK|PSH: Acknowlegement with a push on packet (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(28, 0, 0, 1, 1, 1, 0, 0, 0, 1, 'URG|ACK|PSH: Urgent field active, acknowlegement of packet, and priority data');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(29, 1, 0, 1, 1, 1, 0, 0, 0, 1, 'URG|ACK|PSH: Urgent field active, acknowlegement of packet, and priority data (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(30, 0, 1, 1, 1, 1, 0, 0, 0, 1, 'URG|ACK|PSH: Urgent field active, acknowlegement of packet, and priority data (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(31, 1, 1, 1, 1, 1, 0, 0, 0, 1, 'URG|ACK|PSH: Urgent field active, acknowlegement of packet, and priority data (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(32, 0, 0, 0, 0, 0, 1, 0, 0, 1, 'RST: Reset/Terminate connection immediately');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(33, 1, 0, 0, 0, 0, 1, 0, 0, 1, 'RST: Reset/Terminate connection immediately (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(34, 0, 1, 0, 0, 0, 1, 0, 0, 1, 'RST: Reset/Terminate connection immediately (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(35, 1, 1, 0, 0, 0, 1, 0, 0, 1, 'RST: Reset/Terminate connection immediately (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(36, 0, 0, 1, 0, 0, 1, 0, 0, 0, 'URG|RST: Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(37, 1, 0, 1, 0, 0, 1, 0, 0, 0, 'URG|RST: Standard/Invalid (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(38, 0, 1, 1, 0, 0, 1, 0, 0, 0, 'URG|RST: Standard/Invalid (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(39, 1, 1, 1, 0, 0, 1, 0, 0, 0, 'URG|RST: Standard/Invalid (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(40, 0, 0, 0, 1, 0, 1, 0, 0, 1, 'ACK|RST: Acknowlegement with connection reset');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(41, 1, 0, 0, 1, 0, 1, 0, 0, 1, 'ACK|RST: Acknowlegement with connection reset (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(42, 0, 1, 0, 1, 0, 1, 0, 0, 1, 'ACK|RST: Acknowlegement with connection reset (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(43, 1, 1, 0, 1, 0, 1, 0, 0, 1, 'ACK|RST: Acknowlegement with connection reset (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(44, 0, 0, 1, 1, 0, 1, 0, 0, 0, 'URG|ACK|RST: Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(45, 1, 0, 1, 1, 0, 1, 0, 0, 0, 'URG|ACK|RST: Standard/Invalid (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(46, 0, 1, 1, 1, 0, 1, 0, 0, 0, 'URG|ACK|RST: Standard/Invalid (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(47, 1, 1, 1, 1, 0, 1, 0, 0, 0, 'URG|ACK|RST: Standard/Invalid (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(48, 0, 0, 0, 0, 1, 1, 0, 0, 0, 'PSH|RST: Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(49, 1, 0, 0, 0, 1, 1, 0, 0, 0, 'PSH|RST: Standard/Invalid (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(50, 0, 1, 0, 0, 1, 1, 0, 0, 0, 'PSH|RST: Standard/Invalid (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(51, 1, 1, 0, 0, 1, 1, 0, 0, 0, 'PSH|RST: Standard/Invalid (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(52, 0, 0, 1, 0, 1, 1, 0, 0, 0, 'URG|PSH|RST: Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(53, 1, 0, 1, 0, 1, 1, 0, 0, 0, 'URG|PSH|RST: Standard/Invalid (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(54, 0, 1, 1, 0, 1, 1, 0, 0, 0, 'URG|PSH|RST: Standard/Invalid (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(55, 1, 1, 1, 0, 1, 1, 0, 0, 0, 'URG|PSH|RST: Standard/Invalid (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(56, 0, 0, 0, 1, 1, 1, 0, 0, 1, 'ACK|PSH|RST: Found through numberous false alters, but is legitimate traffic');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(57, 1, 0, 0, 1, 1, 1, 0, 0, 1, 'ACK|PSH|RST: Found through numberous false alters, but is legitimate traffic (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(58, 0, 1, 0, 1, 1, 1, 0, 0, 1, 'ACK|PSH|RST: Found through numberous false alters, but is legitimate traffic (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(59, 1, 1, 0, 1, 1, 1, 0, 0, 1, 'ACK|PSH|RST: Found through numberous false alters, but is legitimate traffic (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(60, 0, 0, 1, 1, 1, 1, 0, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(61, 1, 0, 1, 1, 1, 1, 0, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(62, 0, 1, 1, 1, 1, 1, 0, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(63, 1, 1, 1, 1, 1, 1, 0, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(64, 0, 0, 0, 0, 0, 0, 1, 0, 1, 'SYN: Setup/Initiate Connection');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(65, 1, 0, 0, 0, 0, 0, 1, 0, 1, 'SYN: Setup/Initiate Connection (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(66, 0, 1, 0, 0, 0, 0, 1, 0, 1, 'SYN: Setup/Initiate Connection (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(67, 1, 1, 0, 0, 0, 0, 1, 0, 1, 'SYN: Setup/Initiate Connection (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(68, 0, 0, 1, 0, 0, 0, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(69, 1, 0, 1, 0, 0, 0, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(70, 0, 1, 1, 0, 0, 0, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(71, 1, 1, 1, 0, 0, 0, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(72, 0, 0, 0, 1, 0, 0, 1, 0, 1, 'ACK|SYN: Acknowlege a SYN packet');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(73, 1, 0, 0, 1, 0, 0, 1, 0, 1, 'ACK|SYN: Acknowlege a SYN packet (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(74, 0, 1, 0, 1, 0, 0, 1, 0, 1, 'ACK|SYN: Acknowlege a SYN packet (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(75, 1, 1, 0, 1, 0, 0, 1, 0, 1, 'ACK|SYN: Acknowlege a SYN packet (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(76, 0, 0, 1, 1, 0, 0, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(77, 1, 0, 1, 1, 0, 0, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(78, 0, 1, 1, 1, 0, 0, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(79, 1, 1, 1, 1, 0, 0, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(80, 0, 0, 0, 0, 1, 0, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(81, 1, 0, 0, 0, 1, 0, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(82, 0, 1, 0, 0, 1, 0, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(83, 1, 1, 0, 0, 1, 0, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(84, 0, 0, 1, 0, 1, 0, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(85, 1, 0, 1, 0, 1, 0, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(86, 0, 1, 1, 0, 1, 0, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(87, 1, 1, 1, 0, 1, 0, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(88, 0, 0, 0, 1, 1, 0, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(89, 1, 0, 0, 1, 1, 0, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(90, 0, 1, 0, 1, 1, 0, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(91, 1, 1, 0, 1, 1, 0, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(92, 0, 0, 1, 1, 1, 0, 1, 0, 0, 'URG|ACK|PSH|SYN');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(93, 1, 0, 1, 1, 1, 0, 1, 0, 0, 'URG|ACK|PSH|SYN (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(94, 0, 1, 1, 1, 1, 0, 1, 0, 0, 'URG|ACK|PSH|SYN (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(95, 1, 1, 1, 1, 1, 0, 1, 0, 0, 'URG|ACK|PSH|SYN (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(96, 0, 0, 0, 0, 0, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(97, 1, 0, 0, 0, 0, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(98, 0, 1, 0, 0, 0, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(99, 1, 1, 0, 0, 0, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(100, 0, 0, 1, 0, 0, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(101, 1, 0, 1, 0, 0, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(102, 0, 1, 1, 0, 0, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(103, 1, 1, 1, 0, 0, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(104, 0, 0, 0, 1, 0, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(105, 1, 0, 0, 1, 0, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(106, 0, 1, 0, 1, 0, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(107, 1, 1, 0, 1, 0, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(108, 0, 0, 1, 1, 0, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(109, 1, 0, 1, 1, 0, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(110, 0, 1, 1, 1, 0, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(111, 1, 1, 1, 1, 0, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(112, 0, 0, 0, 0, 1, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(113, 1, 0, 0, 0, 1, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(114, 0, 1, 0, 0, 1, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(115, 1, 1, 0, 0, 1, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(116, 0, 0, 1, 0, 1, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(117, 1, 0, 1, 0, 1, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(118, 0, 1, 1, 0, 1, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(119, 1, 1, 1, 0, 1, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(120, 0, 0, 0, 1, 1, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(121, 1, 0, 0, 1, 1, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(122, 0, 1, 0, 1, 1, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(123, 1, 1, 0, 1, 1, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(124, 0, 0, 1, 1, 1, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(125, 1, 0, 1, 1, 1, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(126, 0, 1, 1, 1, 1, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(127, 1, 1, 1, 1, 1, 1, 1, 0, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(128, 0, 0, 0, 0, 0, 0, 0, 1, 1, 'FIN: Finished sending data through 1/2 connection');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(129, 1, 0, 0, 0, 0, 0, 0, 1, 1, 'FIN: Finished sending data through 1/2 connection (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(130, 0, 1, 0, 0, 0, 0, 0, 1, 1, 'FIN: Finished sending data through 1/2 connection (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(131, 1, 1, 0, 0, 0, 0, 0, 1, 1, 'FIN: Finished sending data through 1/2 connection (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(132, 0, 0, 1, 0, 0, 0, 0, 1, 1, 'URG|RST: Urgent field active and reset connection');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(133, 1, 0, 1, 0, 0, 0, 0, 1, 1, 'URG|RST: Urgent field active and reset connection (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(134, 0, 1, 1, 0, 0, 0, 0, 1, 1, 'URG|RST: Urgent field active and reset connection (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(135, 1, 1, 1, 0, 0, 0, 0, 1, 1, 'URG|RST: Urgent field active and reset connection (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(136, 0, 0, 0, 1, 0, 0, 0, 1, 1, 'SYN|FIN: Finished with connection with acknowlegement of packet');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(137, 1, 0, 0, 1, 0, 0, 0, 1, 1, 'SYN|FIN: Finished with connection with acknowlegement of packet (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(138, 0, 1, 0, 1, 0, 0, 0, 1, 1, 'SYN|FIN: Finished with connection with acknowlegement of packet (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(139, 1, 1, 0, 1, 0, 0, 0, 1, 1, 'SYN|FIN: Finished with connection with acknowlegement of packet (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(140, 0, 0, 1, 1, 0, 0, 0, 1, 1, 'URG|ACK|FIN: Urgent field active, acknowlege packet, and finished sending data');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(141, 1, 0, 1, 1, 0, 0, 0, 1, 1, 'URG|ACK|FIN: Urgent field active, acknowlege packet, and finished sending data (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(142, 0, 1, 1, 1, 0, 0, 0, 1, 1, 'URG|ACK|FIN: Urgent field active, acknowlege packet, and finished sending data (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(143, 1, 1, 1, 1, 0, 0, 0, 1, 1, 'URG|ACK|FIN: Urgent field active, acknowlege packet, and finished sending data (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(144, 0, 0, 0, 0, 1, 0, 0, 1, 1, 'PSH|RST: Push data and reset connection');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(145, 1, 0, 0, 0, 1, 0, 0, 1, 1, 'PSH|RST: Push data and reset connection (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(146, 0, 1, 0, 0, 1, 0, 0, 1, 1, 'PSH|RST: Push data and reset connection (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(147, 1, 1, 0, 0, 1, 0, 0, 1, 1, 'PSH|RST: Push data and reset connection (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(148, 0, 0, 1, 0, 1, 0, 0, 1, 0, 'URG|PSH|FIN: X-mas tree');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(149, 1, 0, 1, 0, 1, 0, 0, 1, 0, 'URG|PSH|FIN: X-mas tree (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(150, 0, 1, 1, 0, 1, 0, 0, 1, 0, 'URG|PSH|FIN: X-mas tree (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(151, 1, 1, 1, 0, 1, 0, 0, 1, 0, 'URG|PSH|FIN: X-mas tree (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(152, 0, 0, 0, 1, 1, 0, 0, 1, 1, 'ACK|PSH|FIN: Acknowlege packet, push data, and finished with connection');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(153, 1, 0, 0, 1, 1, 0, 0, 1, 1, 'ACK|PSH|FIN: Acknowlege packet, push data, and finished with connection (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(154, 0, 1, 0, 1, 1, 0, 0, 1, 1, 'ACK|PSH|FIN: Acknowlege packet, push data, and finished with connection (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(155, 1, 1, 0, 1, 1, 0, 0, 1, 1, 'ACK|PSH|FIN: Acknowlege packet, push data, and finished with connection (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(156, 0, 0, 1, 1, 1, 0, 0, 1, 1, 'URG|ACK|PSH|FIN: Urgent field active, acknowlege packet, push data, and finished sending data');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(157, 1, 0, 1, 1, 1, 0, 0, 1, 1, 'URG|ACK|PSH|FIN: Urgent field active, acknowlege packet, push data, and finished sending data (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(158, 0, 1, 1, 1, 1, 0, 0, 1, 1, 'URG|ACK|PSH|FIN: Urgent field active, acknowlege packet, push data, and finished sending data (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(159, 1, 1, 1, 1, 1, 0, 0, 1, 1, 'URG|ACK|PSH|FIN: Urgent field active, acknowlege packet, push data, and finished sending data (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(160, 0, 0, 0, 0, 0, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(161, 1, 0, 0, 0, 0, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(162, 0, 1, 0, 0, 0, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(163, 1, 1, 0, 0, 0, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(164, 0, 0, 1, 0, 0, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(165, 1, 0, 1, 0, 0, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(166, 0, 1, 1, 0, 0, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(167, 1, 1, 1, 0, 0, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(168, 0, 0, 0, 1, 0, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(169, 1, 0, 0, 1, 0, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(170, 0, 1, 0, 1, 0, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(171, 1, 1, 0, 1, 0, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(172, 0, 0, 1, 1, 0, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(173, 1, 0, 1, 1, 0, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(174, 0, 1, 1, 1, 0, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(175, 1, 1, 1, 1, 0, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(176, 0, 0, 0, 0, 1, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(177, 1, 0, 0, 0, 1, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(178, 0, 1, 0, 0, 1, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(179, 1, 1, 0, 0, 1, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(180, 0, 0, 1, 0, 1, 1, 0, 1, 0, 'URG|PSH|RST|FIN: Kamakaze packet if it has one byte of data');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(181, 1, 0, 1, 0, 1, 1, 0, 1, 0, 'URG|PSH|RST|FIN: Kamakaze packet if it has one byte of data (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(182, 0, 1, 1, 0, 1, 1, 0, 1, 0, 'URG|PSH|RST|FIN: Kamakaze packet if it has one byte of data (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(183, 1, 1, 1, 0, 1, 1, 0, 1, 0, 'URG|PSH|RST|FIN: Kamakaze packet if it has one byte of data (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(184, 0, 0, 0, 1, 1, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(185, 1, 0, 0, 1, 1, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(186, 0, 1, 0, 1, 1, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(187, 1, 1, 0, 1, 1, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(188, 0, 0, 1, 1, 1, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(189, 1, 0, 1, 1, 1, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(190, 0, 1, 1, 1, 1, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(191, 1, 1, 1, 1, 1, 1, 0, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(192, 0, 0, 0, 0, 0, 0, 1, 1, 0, 'SYN|FIN: "SYN|FIN scan" generates a reply if port is open (reply-> ) or closed (reply-> RST|SCK)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(193, 1, 0, 0, 0, 0, 0, 1, 1, 0, 'SYN|FIN: "SYN|FIN scan" generates a reply if port is open (reply-> ) or closed (reply-> RST|SCK) (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(194, 0, 1, 0, 0, 0, 0, 1, 1, 0, 'SYN|FIN: "SYN|FIN scan" generates a reply if port is open (reply-> ) or closed (reply-> RST|SCK) (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(195, 1, 1, 0, 0, 0, 0, 1, 1, 0, 'SYN|FIN: "SYN|FIN scan" generates a reply if port is open (reply-> ) or closed (reply-> RST|SCK) (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(196, 0, 0, 1, 0, 0, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(197, 1, 0, 1, 0, 0, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(198, 0, 1, 1, 0, 0, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(199, 1, 1, 1, 0, 0, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(200, 0, 0, 0, 1, 0, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(201, 1, 0, 0, 1, 0, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(202, 0, 1, 0, 1, 0, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(203, 1, 1, 0, 1, 0, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(204, 0, 0, 1, 1, 0, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(205, 1, 0, 1, 1, 0, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(206, 0, 1, 1, 1, 0, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(207, 1, 1, 1, 1, 0, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(208, 0, 0, 0, 0, 1, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(209, 1, 0, 0, 0, 1, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(210, 0, 1, 0, 0, 1, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(211, 1, 1, 0, 0, 1, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(212, 0, 0, 1, 0, 1, 0, 1, 1, 0, 'URG|PSH|SYN|FIN: NMAPID');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(213, 1, 0, 1, 0, 1, 0, 1, 1, 0, 'URG|PSH|SYN|FIN: NMAPID (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(214, 0, 1, 1, 0, 1, 0, 1, 1, 0, 'URG|PSH|SYN|FIN: NMAPID (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(215, 1, 1, 1, 0, 1, 0, 1, 1, 0, 'URG|PSH|SYN|FIN: NMAPID (reserved bit 1 & 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(216, 0, 0, 0, 1, 1, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(217, 1, 0, 0, 1, 1, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(218, 0, 1, 0, 1, 1, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(219, 1, 1, 0, 1, 1, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(220, 0, 0, 1, 1, 1, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(221, 1, 0, 1, 1, 1, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(222, 0, 1, 1, 1, 1, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(223, 1, 1, 1, 1, 1, 0, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(224, 0, 0, 0, 0, 0, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(225, 1, 0, 0, 0, 0, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(226, 0, 1, 0, 0, 0, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(227, 1, 1, 0, 0, 0, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(228, 0, 0, 1, 0, 0, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(229, 1, 0, 1, 0, 0, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(230, 0, 1, 1, 0, 0, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(231, 1, 1, 1, 0, 0, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(232, 0, 0, 0, 1, 0, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(233, 1, 0, 0, 1, 0, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(234, 0, 1, 0, 1, 0, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(235, 1, 1, 0, 1, 0, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(236, 0, 0, 1, 1, 0, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(237, 1, 0, 1, 1, 0, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(238, 0, 1, 1, 1, 0, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(239, 1, 1, 1, 1, 0, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(240, 0, 0, 0, 0, 1, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(241, 1, 0, 0, 0, 1, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(242, 0, 1, 0, 0, 1, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(243, 1, 1, 0, 0, 1, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(244, 0, 0, 1, 0, 1, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(245, 1, 0, 1, 0, 1, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(246, 0, 1, 1, 0, 1, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(247, 1, 1, 1, 0, 1, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(248, 0, 0, 0, 1, 1, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(249, 1, 0, 0, 1, 1, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(250, 0, 1, 0, 1, 1, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(251, 1, 1, 0, 1, 1, 1, 1, 1, 0, 'Standard/Invalid');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(252, 0, 0, 1, 1, 1, 1, 1, 1, 0, 'URG|ACK|PSH|RST|SYN|FIN: FULL X-mas tree');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(253, 1, 0, 1, 1, 1, 1, 1, 1, 0, 'URG|ACK|PSH|RST|SYN|FIN: FULL X-mas tree (reserved bit 1 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(254, 0, 1, 1, 1, 1, 1, 1, 1, 0, 'URG|ACK|PSH|RST|SYN|FIN: FULL X-mas tree (reserved bit 2 active)');
INSERT INTO flags(number, RES1, RES2, URG, ACK, PSH, RST, SYN, FIN, valid, description) VALUES(255, 1, 1, 1, 1, 1, 1, 1, 1, 0, 'URG|ACK|PSH|RST|SYN|FIN: FULL X-mas tree (reserved bit 1 & 2 active)');
